// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: proto/services/serviceReply.proto

package ubii.services;

public final class ServiceReplyOuterClass {
  private ServiceReplyOuterClass() {}
  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistryLite registry) {
  }

  public static void registerAllExtensions(
      com.google.protobuf.ExtensionRegistry registry) {
    registerAllExtensions(
        (com.google.protobuf.ExtensionRegistryLite) registry);
  }
  public interface ServiceReplyOrBuilder extends
      // @@protoc_insertion_point(interface_extends:ubii.services.ServiceReply)
      com.google.protobuf.MessageOrBuilder {

    /**
     * <code>.ubii.general.Success success = 1;</code>
     */
    boolean hasSuccess();
    /**
     * <code>.ubii.general.Success success = 1;</code>
     */
    ubii.general.SuccessOuterClass.Success getSuccess();
    /**
     * <code>.ubii.general.Success success = 1;</code>
     */
    ubii.general.SuccessOuterClass.SuccessOrBuilder getSuccessOrBuilder();

    /**
     * <code>.ubii.general.Error error = 2;</code>
     */
    boolean hasError();
    /**
     * <code>.ubii.general.Error error = 2;</code>
     */
    ubii.general.ErrorOuterClass.Error getError();
    /**
     * <code>.ubii.general.Error error = 2;</code>
     */
    ubii.general.ErrorOuterClass.ErrorOrBuilder getErrorOrBuilder();

    /**
     * <code>.ubii.clients.Client client = 3;</code>
     */
    boolean hasClient();
    /**
     * <code>.ubii.clients.Client client = 3;</code>
     */
    ubii.clients.ClientOuterClass.Client getClient();
    /**
     * <code>.ubii.clients.Client client = 3;</code>
     */
    ubii.clients.ClientOuterClass.ClientOrBuilder getClientOrBuilder();

    /**
     * <code>.ubii.devices.Device device = 4;</code>
     */
    boolean hasDevice();
    /**
     * <code>.ubii.devices.Device device = 4;</code>
     */
    ubii.devices.DeviceOuterClass.Device getDevice();
    /**
     * <code>.ubii.devices.Device device = 4;</code>
     */
    ubii.devices.DeviceOuterClass.DeviceOrBuilder getDeviceOrBuilder();

    /**
     * <code>.ubii.servers.Server server = 5;</code>
     */
    boolean hasServer();
    /**
     * <code>.ubii.servers.Server server = 5;</code>
     */
    ubii.servers.ServerOuterClass.Server getServer();
    /**
     * <code>.ubii.servers.Server server = 5;</code>
     */
    ubii.servers.ServerOuterClass.ServerOrBuilder getServerOrBuilder();

    /**
     * <code>.ubii.sessions.Session session = 6;</code>
     */
    boolean hasSession();
    /**
     * <code>.ubii.sessions.Session session = 6;</code>
     */
    ubii.sessions.SessionOuterClass.Session getSession();
    /**
     * <code>.ubii.sessions.Session session = 6;</code>
     */
    ubii.sessions.SessionOuterClass.SessionOrBuilder getSessionOrBuilder();

    /**
     * <code>.ubii.sessions.SessionList session_list = 7;</code>
     */
    boolean hasSessionList();
    /**
     * <code>.ubii.sessions.SessionList session_list = 7;</code>
     */
    ubii.sessions.SessionOuterClass.SessionList getSessionList();
    /**
     * <code>.ubii.sessions.SessionList session_list = 7;</code>
     */
    ubii.sessions.SessionOuterClass.SessionListOrBuilder getSessionListOrBuilder();

    /**
     * <code>.ubii.processing.ProcessingModule processing_module = 8;</code>
     */
    boolean hasProcessingModule();
    /**
     * <code>.ubii.processing.ProcessingModule processing_module = 8;</code>
     */
    ubii.processing.ProcessingModuleOuterClass.ProcessingModule getProcessingModule();
    /**
     * <code>.ubii.processing.ProcessingModule processing_module = 8;</code>
     */
    ubii.processing.ProcessingModuleOuterClass.ProcessingModuleOrBuilder getProcessingModuleOrBuilder();

    /**
     * <code>.ubii.processing.ProcessingModuleList processing_module_list = 9;</code>
     */
    boolean hasProcessingModuleList();
    /**
     * <code>.ubii.processing.ProcessingModuleList processing_module_list = 9;</code>
     */
    ubii.processing.ProcessingModuleOuterClass.ProcessingModuleList getProcessingModuleList();
    /**
     * <code>.ubii.processing.ProcessingModuleList processing_module_list = 9;</code>
     */
    ubii.processing.ProcessingModuleOuterClass.ProcessingModuleListOrBuilder getProcessingModuleListOrBuilder();

    /**
     * <code>.ubii.dataStructure.StringList string_list = 10;</code>
     */
    boolean hasStringList();
    /**
     * <code>.ubii.dataStructure.StringList string_list = 10;</code>
     */
    ubii.dataStructure.Lists.StringList getStringList();
    /**
     * <code>.ubii.dataStructure.StringList string_list = 10;</code>
     */
    ubii.dataStructure.Lists.StringListOrBuilder getStringListOrBuilder();

    /**
     * <code>.ubii.devices.TopicMux topic_mux = 11;</code>
     */
    boolean hasTopicMux();
    /**
     * <code>.ubii.devices.TopicMux topic_mux = 11;</code>
     */
    ubii.devices.TopicMuxOuterClass.TopicMux getTopicMux();
    /**
     * <code>.ubii.devices.TopicMux topic_mux = 11;</code>
     */
    ubii.devices.TopicMuxOuterClass.TopicMuxOrBuilder getTopicMuxOrBuilder();

    /**
     * <code>.ubii.devices.TopicMuxList topic_mux_list = 12;</code>
     */
    boolean hasTopicMuxList();
    /**
     * <code>.ubii.devices.TopicMuxList topic_mux_list = 12;</code>
     */
    ubii.devices.TopicMuxOuterClass.TopicMuxList getTopicMuxList();
    /**
     * <code>.ubii.devices.TopicMuxList topic_mux_list = 12;</code>
     */
    ubii.devices.TopicMuxOuterClass.TopicMuxListOrBuilder getTopicMuxListOrBuilder();

    /**
     * <code>.ubii.devices.TopicDemux topic_demux = 13;</code>
     */
    boolean hasTopicDemux();
    /**
     * <code>.ubii.devices.TopicDemux topic_demux = 13;</code>
     */
    ubii.devices.TopicDemuxOuterClass.TopicDemux getTopicDemux();
    /**
     * <code>.ubii.devices.TopicDemux topic_demux = 13;</code>
     */
    ubii.devices.TopicDemuxOuterClass.TopicDemuxOrBuilder getTopicDemuxOrBuilder();

    /**
     * <code>.ubii.devices.TopicDemuxList topic_demux_list = 14;</code>
     */
    boolean hasTopicDemuxList();
    /**
     * <code>.ubii.devices.TopicDemuxList topic_demux_list = 14;</code>
     */
    ubii.devices.TopicDemuxOuterClass.TopicDemuxList getTopicDemuxList();
    /**
     * <code>.ubii.devices.TopicDemuxList topic_demux_list = 14;</code>
     */
    ubii.devices.TopicDemuxOuterClass.TopicDemuxListOrBuilder getTopicDemuxListOrBuilder();

    /**
     * <code>.ubii.clients.ClientList client_list = 15;</code>
     */
    boolean hasClientList();
    /**
     * <code>.ubii.clients.ClientList client_list = 15;</code>
     */
    ubii.clients.ClientOuterClass.ClientList getClientList();
    /**
     * <code>.ubii.clients.ClientList client_list = 15;</code>
     */
    ubii.clients.ClientOuterClass.ClientListOrBuilder getClientListOrBuilder();

    /**
     * <code>.ubii.devices.DeviceList device_list = 16;</code>
     */
    boolean hasDeviceList();
    /**
     * <code>.ubii.devices.DeviceList device_list = 16;</code>
     */
    ubii.devices.DeviceOuterClass.DeviceList getDeviceList();
    /**
     * <code>.ubii.devices.DeviceList device_list = 16;</code>
     */
    ubii.devices.DeviceOuterClass.DeviceListOrBuilder getDeviceListOrBuilder();

    /**
     * <code>.ubii.services.Service service = 17;</code>
     */
    boolean hasService();
    /**
     * <code>.ubii.services.Service service = 17;</code>
     */
    ubii.services.ServiceOuterClass.Service getService();
    /**
     * <code>.ubii.services.Service service = 17;</code>
     */
    ubii.services.ServiceOuterClass.ServiceOrBuilder getServiceOrBuilder();

    /**
     * <code>.ubii.services.ServiceList service_list = 18;</code>
     */
    boolean hasServiceList();
    /**
     * <code>.ubii.services.ServiceList service_list = 18;</code>
     */
    ubii.services.ServiceOuterClass.ServiceList getServiceList();
    /**
     * <code>.ubii.services.ServiceList service_list = 18;</code>
     */
    ubii.services.ServiceOuterClass.ServiceListOrBuilder getServiceListOrBuilder();

    /**
     * <code>.ubii.processing.LockstepProcessingReply lockstep_processing_reply = 19;</code>
     */
    boolean hasLockstepProcessingReply();
    /**
     * <code>.ubii.processing.LockstepProcessingReply lockstep_processing_reply = 19;</code>
     */
    ubii.processing.LockstepProcessing.LockstepProcessingReply getLockstepProcessingReply();
    /**
     * <code>.ubii.processing.LockstepProcessingReply lockstep_processing_reply = 19;</code>
     */
    ubii.processing.LockstepProcessing.LockstepProcessingReplyOrBuilder getLockstepProcessingReplyOrBuilder();

    public ubii.services.ServiceReplyOuterClass.ServiceReply.TypeCase getTypeCase();
  }
  /**
   * Protobuf type {@code ubii.services.ServiceReply}
   */
  public  static final class ServiceReply extends
      com.google.protobuf.GeneratedMessageV3 implements
      // @@protoc_insertion_point(message_implements:ubii.services.ServiceReply)
      ServiceReplyOrBuilder {
  private static final long serialVersionUID = 0L;
    // Use ServiceReply.newBuilder() to construct.
    private ServiceReply(com.google.protobuf.GeneratedMessageV3.Builder<?> builder) {
      super(builder);
    }
    private ServiceReply() {
    }

    @java.lang.Override
    public final com.google.protobuf.UnknownFieldSet
    getUnknownFields() {
      return this.unknownFields;
    }
    private ServiceReply(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      this();
      if (extensionRegistry == null) {
        throw new java.lang.NullPointerException();
      }
      int mutable_bitField0_ = 0;
      com.google.protobuf.UnknownFieldSet.Builder unknownFields =
          com.google.protobuf.UnknownFieldSet.newBuilder();
      try {
        boolean done = false;
        while (!done) {
          int tag = input.readTag();
          switch (tag) {
            case 0:
              done = true;
              break;
            case 10: {
              ubii.general.SuccessOuterClass.Success.Builder subBuilder = null;
              if (typeCase_ == 1) {
                subBuilder = ((ubii.general.SuccessOuterClass.Success) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.general.SuccessOuterClass.Success.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.general.SuccessOuterClass.Success) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 1;
              break;
            }
            case 18: {
              ubii.general.ErrorOuterClass.Error.Builder subBuilder = null;
              if (typeCase_ == 2) {
                subBuilder = ((ubii.general.ErrorOuterClass.Error) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.general.ErrorOuterClass.Error.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.general.ErrorOuterClass.Error) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 2;
              break;
            }
            case 26: {
              ubii.clients.ClientOuterClass.Client.Builder subBuilder = null;
              if (typeCase_ == 3) {
                subBuilder = ((ubii.clients.ClientOuterClass.Client) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.clients.ClientOuterClass.Client.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.clients.ClientOuterClass.Client) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 3;
              break;
            }
            case 34: {
              ubii.devices.DeviceOuterClass.Device.Builder subBuilder = null;
              if (typeCase_ == 4) {
                subBuilder = ((ubii.devices.DeviceOuterClass.Device) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.devices.DeviceOuterClass.Device.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.devices.DeviceOuterClass.Device) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 4;
              break;
            }
            case 42: {
              ubii.servers.ServerOuterClass.Server.Builder subBuilder = null;
              if (typeCase_ == 5) {
                subBuilder = ((ubii.servers.ServerOuterClass.Server) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.servers.ServerOuterClass.Server.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.servers.ServerOuterClass.Server) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 5;
              break;
            }
            case 50: {
              ubii.sessions.SessionOuterClass.Session.Builder subBuilder = null;
              if (typeCase_ == 6) {
                subBuilder = ((ubii.sessions.SessionOuterClass.Session) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.sessions.SessionOuterClass.Session.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.sessions.SessionOuterClass.Session) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 6;
              break;
            }
            case 58: {
              ubii.sessions.SessionOuterClass.SessionList.Builder subBuilder = null;
              if (typeCase_ == 7) {
                subBuilder = ((ubii.sessions.SessionOuterClass.SessionList) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.sessions.SessionOuterClass.SessionList.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.sessions.SessionOuterClass.SessionList) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 7;
              break;
            }
            case 66: {
              ubii.processing.ProcessingModuleOuterClass.ProcessingModule.Builder subBuilder = null;
              if (typeCase_ == 8) {
                subBuilder = ((ubii.processing.ProcessingModuleOuterClass.ProcessingModule) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.processing.ProcessingModuleOuterClass.ProcessingModule.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.processing.ProcessingModuleOuterClass.ProcessingModule) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 8;
              break;
            }
            case 74: {
              ubii.processing.ProcessingModuleOuterClass.ProcessingModuleList.Builder subBuilder = null;
              if (typeCase_ == 9) {
                subBuilder = ((ubii.processing.ProcessingModuleOuterClass.ProcessingModuleList) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.processing.ProcessingModuleOuterClass.ProcessingModuleList.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.processing.ProcessingModuleOuterClass.ProcessingModuleList) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 9;
              break;
            }
            case 82: {
              ubii.dataStructure.Lists.StringList.Builder subBuilder = null;
              if (typeCase_ == 10) {
                subBuilder = ((ubii.dataStructure.Lists.StringList) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.dataStructure.Lists.StringList.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.dataStructure.Lists.StringList) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 10;
              break;
            }
            case 90: {
              ubii.devices.TopicMuxOuterClass.TopicMux.Builder subBuilder = null;
              if (typeCase_ == 11) {
                subBuilder = ((ubii.devices.TopicMuxOuterClass.TopicMux) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.devices.TopicMuxOuterClass.TopicMux.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.devices.TopicMuxOuterClass.TopicMux) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 11;
              break;
            }
            case 98: {
              ubii.devices.TopicMuxOuterClass.TopicMuxList.Builder subBuilder = null;
              if (typeCase_ == 12) {
                subBuilder = ((ubii.devices.TopicMuxOuterClass.TopicMuxList) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.devices.TopicMuxOuterClass.TopicMuxList.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.devices.TopicMuxOuterClass.TopicMuxList) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 12;
              break;
            }
            case 106: {
              ubii.devices.TopicDemuxOuterClass.TopicDemux.Builder subBuilder = null;
              if (typeCase_ == 13) {
                subBuilder = ((ubii.devices.TopicDemuxOuterClass.TopicDemux) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.devices.TopicDemuxOuterClass.TopicDemux.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.devices.TopicDemuxOuterClass.TopicDemux) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 13;
              break;
            }
            case 114: {
              ubii.devices.TopicDemuxOuterClass.TopicDemuxList.Builder subBuilder = null;
              if (typeCase_ == 14) {
                subBuilder = ((ubii.devices.TopicDemuxOuterClass.TopicDemuxList) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.devices.TopicDemuxOuterClass.TopicDemuxList.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.devices.TopicDemuxOuterClass.TopicDemuxList) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 14;
              break;
            }
            case 122: {
              ubii.clients.ClientOuterClass.ClientList.Builder subBuilder = null;
              if (typeCase_ == 15) {
                subBuilder = ((ubii.clients.ClientOuterClass.ClientList) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.clients.ClientOuterClass.ClientList.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.clients.ClientOuterClass.ClientList) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 15;
              break;
            }
            case 130: {
              ubii.devices.DeviceOuterClass.DeviceList.Builder subBuilder = null;
              if (typeCase_ == 16) {
                subBuilder = ((ubii.devices.DeviceOuterClass.DeviceList) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.devices.DeviceOuterClass.DeviceList.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.devices.DeviceOuterClass.DeviceList) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 16;
              break;
            }
            case 138: {
              ubii.services.ServiceOuterClass.Service.Builder subBuilder = null;
              if (typeCase_ == 17) {
                subBuilder = ((ubii.services.ServiceOuterClass.Service) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.services.ServiceOuterClass.Service.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.services.ServiceOuterClass.Service) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 17;
              break;
            }
            case 146: {
              ubii.services.ServiceOuterClass.ServiceList.Builder subBuilder = null;
              if (typeCase_ == 18) {
                subBuilder = ((ubii.services.ServiceOuterClass.ServiceList) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.services.ServiceOuterClass.ServiceList.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.services.ServiceOuterClass.ServiceList) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 18;
              break;
            }
            case 154: {
              ubii.processing.LockstepProcessing.LockstepProcessingReply.Builder subBuilder = null;
              if (typeCase_ == 19) {
                subBuilder = ((ubii.processing.LockstepProcessing.LockstepProcessingReply) type_).toBuilder();
              }
              type_ =
                  input.readMessage(ubii.processing.LockstepProcessing.LockstepProcessingReply.parser(), extensionRegistry);
              if (subBuilder != null) {
                subBuilder.mergeFrom((ubii.processing.LockstepProcessing.LockstepProcessingReply) type_);
                type_ = subBuilder.buildPartial();
              }
              typeCase_ = 19;
              break;
            }
            default: {
              if (!parseUnknownFieldProto3(
                  input, unknownFields, extensionRegistry, tag)) {
                done = true;
              }
              break;
            }
          }
        }
      } catch (com.google.protobuf.InvalidProtocolBufferException e) {
        throw e.setUnfinishedMessage(this);
      } catch (java.io.IOException e) {
        throw new com.google.protobuf.InvalidProtocolBufferException(
            e).setUnfinishedMessage(this);
      } finally {
        this.unknownFields = unknownFields.build();
        makeExtensionsImmutable();
      }
    }
    public static final com.google.protobuf.Descriptors.Descriptor
        getDescriptor() {
      return ubii.services.ServiceReplyOuterClass.internal_static_ubii_services_ServiceReply_descriptor;
    }

    @java.lang.Override
    protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
        internalGetFieldAccessorTable() {
      return ubii.services.ServiceReplyOuterClass.internal_static_ubii_services_ServiceReply_fieldAccessorTable
          .ensureFieldAccessorsInitialized(
              ubii.services.ServiceReplyOuterClass.ServiceReply.class, ubii.services.ServiceReplyOuterClass.ServiceReply.Builder.class);
    }

    private int typeCase_ = 0;
    private java.lang.Object type_;
    public enum TypeCase
        implements com.google.protobuf.Internal.EnumLite {
      SUCCESS(1),
      ERROR(2),
      CLIENT(3),
      DEVICE(4),
      SERVER(5),
      SESSION(6),
      SESSION_LIST(7),
      PROCESSING_MODULE(8),
      PROCESSING_MODULE_LIST(9),
      STRING_LIST(10),
      TOPIC_MUX(11),
      TOPIC_MUX_LIST(12),
      TOPIC_DEMUX(13),
      TOPIC_DEMUX_LIST(14),
      CLIENT_LIST(15),
      DEVICE_LIST(16),
      SERVICE(17),
      SERVICE_LIST(18),
      LOCKSTEP_PROCESSING_REPLY(19),
      TYPE_NOT_SET(0);
      private final int value;
      private TypeCase(int value) {
        this.value = value;
      }
      /**
       * @deprecated Use {@link #forNumber(int)} instead.
       */
      @java.lang.Deprecated
      public static TypeCase valueOf(int value) {
        return forNumber(value);
      }

      public static TypeCase forNumber(int value) {
        switch (value) {
          case 1: return SUCCESS;
          case 2: return ERROR;
          case 3: return CLIENT;
          case 4: return DEVICE;
          case 5: return SERVER;
          case 6: return SESSION;
          case 7: return SESSION_LIST;
          case 8: return PROCESSING_MODULE;
          case 9: return PROCESSING_MODULE_LIST;
          case 10: return STRING_LIST;
          case 11: return TOPIC_MUX;
          case 12: return TOPIC_MUX_LIST;
          case 13: return TOPIC_DEMUX;
          case 14: return TOPIC_DEMUX_LIST;
          case 15: return CLIENT_LIST;
          case 16: return DEVICE_LIST;
          case 17: return SERVICE;
          case 18: return SERVICE_LIST;
          case 19: return LOCKSTEP_PROCESSING_REPLY;
          case 0: return TYPE_NOT_SET;
          default: return null;
        }
      }
      public int getNumber() {
        return this.value;
      }
    };

    public TypeCase
    getTypeCase() {
      return TypeCase.forNumber(
          typeCase_);
    }

    public static final int SUCCESS_FIELD_NUMBER = 1;
    /**
     * <code>.ubii.general.Success success = 1;</code>
     */
    public boolean hasSuccess() {
      return typeCase_ == 1;
    }
    /**
     * <code>.ubii.general.Success success = 1;</code>
     */
    public ubii.general.SuccessOuterClass.Success getSuccess() {
      if (typeCase_ == 1) {
         return (ubii.general.SuccessOuterClass.Success) type_;
      }
      return ubii.general.SuccessOuterClass.Success.getDefaultInstance();
    }
    /**
     * <code>.ubii.general.Success success = 1;</code>
     */
    public ubii.general.SuccessOuterClass.SuccessOrBuilder getSuccessOrBuilder() {
      if (typeCase_ == 1) {
         return (ubii.general.SuccessOuterClass.Success) type_;
      }
      return ubii.general.SuccessOuterClass.Success.getDefaultInstance();
    }

    public static final int ERROR_FIELD_NUMBER = 2;
    /**
     * <code>.ubii.general.Error error = 2;</code>
     */
    public boolean hasError() {
      return typeCase_ == 2;
    }
    /**
     * <code>.ubii.general.Error error = 2;</code>
     */
    public ubii.general.ErrorOuterClass.Error getError() {
      if (typeCase_ == 2) {
         return (ubii.general.ErrorOuterClass.Error) type_;
      }
      return ubii.general.ErrorOuterClass.Error.getDefaultInstance();
    }
    /**
     * <code>.ubii.general.Error error = 2;</code>
     */
    public ubii.general.ErrorOuterClass.ErrorOrBuilder getErrorOrBuilder() {
      if (typeCase_ == 2) {
         return (ubii.general.ErrorOuterClass.Error) type_;
      }
      return ubii.general.ErrorOuterClass.Error.getDefaultInstance();
    }

    public static final int CLIENT_FIELD_NUMBER = 3;
    /**
     * <code>.ubii.clients.Client client = 3;</code>
     */
    public boolean hasClient() {
      return typeCase_ == 3;
    }
    /**
     * <code>.ubii.clients.Client client = 3;</code>
     */
    public ubii.clients.ClientOuterClass.Client getClient() {
      if (typeCase_ == 3) {
         return (ubii.clients.ClientOuterClass.Client) type_;
      }
      return ubii.clients.ClientOuterClass.Client.getDefaultInstance();
    }
    /**
     * <code>.ubii.clients.Client client = 3;</code>
     */
    public ubii.clients.ClientOuterClass.ClientOrBuilder getClientOrBuilder() {
      if (typeCase_ == 3) {
         return (ubii.clients.ClientOuterClass.Client) type_;
      }
      return ubii.clients.ClientOuterClass.Client.getDefaultInstance();
    }

    public static final int DEVICE_FIELD_NUMBER = 4;
    /**
     * <code>.ubii.devices.Device device = 4;</code>
     */
    public boolean hasDevice() {
      return typeCase_ == 4;
    }
    /**
     * <code>.ubii.devices.Device device = 4;</code>
     */
    public ubii.devices.DeviceOuterClass.Device getDevice() {
      if (typeCase_ == 4) {
         return (ubii.devices.DeviceOuterClass.Device) type_;
      }
      return ubii.devices.DeviceOuterClass.Device.getDefaultInstance();
    }
    /**
     * <code>.ubii.devices.Device device = 4;</code>
     */
    public ubii.devices.DeviceOuterClass.DeviceOrBuilder getDeviceOrBuilder() {
      if (typeCase_ == 4) {
         return (ubii.devices.DeviceOuterClass.Device) type_;
      }
      return ubii.devices.DeviceOuterClass.Device.getDefaultInstance();
    }

    public static final int SERVER_FIELD_NUMBER = 5;
    /**
     * <code>.ubii.servers.Server server = 5;</code>
     */
    public boolean hasServer() {
      return typeCase_ == 5;
    }
    /**
     * <code>.ubii.servers.Server server = 5;</code>
     */
    public ubii.servers.ServerOuterClass.Server getServer() {
      if (typeCase_ == 5) {
         return (ubii.servers.ServerOuterClass.Server) type_;
      }
      return ubii.servers.ServerOuterClass.Server.getDefaultInstance();
    }
    /**
     * <code>.ubii.servers.Server server = 5;</code>
     */
    public ubii.servers.ServerOuterClass.ServerOrBuilder getServerOrBuilder() {
      if (typeCase_ == 5) {
         return (ubii.servers.ServerOuterClass.Server) type_;
      }
      return ubii.servers.ServerOuterClass.Server.getDefaultInstance();
    }

    public static final int SESSION_FIELD_NUMBER = 6;
    /**
     * <code>.ubii.sessions.Session session = 6;</code>
     */
    public boolean hasSession() {
      return typeCase_ == 6;
    }
    /**
     * <code>.ubii.sessions.Session session = 6;</code>
     */
    public ubii.sessions.SessionOuterClass.Session getSession() {
      if (typeCase_ == 6) {
         return (ubii.sessions.SessionOuterClass.Session) type_;
      }
      return ubii.sessions.SessionOuterClass.Session.getDefaultInstance();
    }
    /**
     * <code>.ubii.sessions.Session session = 6;</code>
     */
    public ubii.sessions.SessionOuterClass.SessionOrBuilder getSessionOrBuilder() {
      if (typeCase_ == 6) {
         return (ubii.sessions.SessionOuterClass.Session) type_;
      }
      return ubii.sessions.SessionOuterClass.Session.getDefaultInstance();
    }

    public static final int SESSION_LIST_FIELD_NUMBER = 7;
    /**
     * <code>.ubii.sessions.SessionList session_list = 7;</code>
     */
    public boolean hasSessionList() {
      return typeCase_ == 7;
    }
    /**
     * <code>.ubii.sessions.SessionList session_list = 7;</code>
     */
    public ubii.sessions.SessionOuterClass.SessionList getSessionList() {
      if (typeCase_ == 7) {
         return (ubii.sessions.SessionOuterClass.SessionList) type_;
      }
      return ubii.sessions.SessionOuterClass.SessionList.getDefaultInstance();
    }
    /**
     * <code>.ubii.sessions.SessionList session_list = 7;</code>
     */
    public ubii.sessions.SessionOuterClass.SessionListOrBuilder getSessionListOrBuilder() {
      if (typeCase_ == 7) {
         return (ubii.sessions.SessionOuterClass.SessionList) type_;
      }
      return ubii.sessions.SessionOuterClass.SessionList.getDefaultInstance();
    }

    public static final int PROCESSING_MODULE_FIELD_NUMBER = 8;
    /**
     * <code>.ubii.processing.ProcessingModule processing_module = 8;</code>
     */
    public boolean hasProcessingModule() {
      return typeCase_ == 8;
    }
    /**
     * <code>.ubii.processing.ProcessingModule processing_module = 8;</code>
     */
    public ubii.processing.ProcessingModuleOuterClass.ProcessingModule getProcessingModule() {
      if (typeCase_ == 8) {
         return (ubii.processing.ProcessingModuleOuterClass.ProcessingModule) type_;
      }
      return ubii.processing.ProcessingModuleOuterClass.ProcessingModule.getDefaultInstance();
    }
    /**
     * <code>.ubii.processing.ProcessingModule processing_module = 8;</code>
     */
    public ubii.processing.ProcessingModuleOuterClass.ProcessingModuleOrBuilder getProcessingModuleOrBuilder() {
      if (typeCase_ == 8) {
         return (ubii.processing.ProcessingModuleOuterClass.ProcessingModule) type_;
      }
      return ubii.processing.ProcessingModuleOuterClass.ProcessingModule.getDefaultInstance();
    }

    public static final int PROCESSING_MODULE_LIST_FIELD_NUMBER = 9;
    /**
     * <code>.ubii.processing.ProcessingModuleList processing_module_list = 9;</code>
     */
    public boolean hasProcessingModuleList() {
      return typeCase_ == 9;
    }
    /**
     * <code>.ubii.processing.ProcessingModuleList processing_module_list = 9;</code>
     */
    public ubii.processing.ProcessingModuleOuterClass.ProcessingModuleList getProcessingModuleList() {
      if (typeCase_ == 9) {
         return (ubii.processing.ProcessingModuleOuterClass.ProcessingModuleList) type_;
      }
      return ubii.processing.ProcessingModuleOuterClass.ProcessingModuleList.getDefaultInstance();
    }
    /**
     * <code>.ubii.processing.ProcessingModuleList processing_module_list = 9;</code>
     */
    public ubii.processing.ProcessingModuleOuterClass.ProcessingModuleListOrBuilder getProcessingModuleListOrBuilder() {
      if (typeCase_ == 9) {
         return (ubii.processing.ProcessingModuleOuterClass.ProcessingModuleList) type_;
      }
      return ubii.processing.ProcessingModuleOuterClass.ProcessingModuleList.getDefaultInstance();
    }

    public static final int STRING_LIST_FIELD_NUMBER = 10;
    /**
     * <code>.ubii.dataStructure.StringList string_list = 10;</code>
     */
    public boolean hasStringList() {
      return typeCase_ == 10;
    }
    /**
     * <code>.ubii.dataStructure.StringList string_list = 10;</code>
     */
    public ubii.dataStructure.Lists.StringList getStringList() {
      if (typeCase_ == 10) {
         return (ubii.dataStructure.Lists.StringList) type_;
      }
      return ubii.dataStructure.Lists.StringList.getDefaultInstance();
    }
    /**
     * <code>.ubii.dataStructure.StringList string_list = 10;</code>
     */
    public ubii.dataStructure.Lists.StringListOrBuilder getStringListOrBuilder() {
      if (typeCase_ == 10) {
         return (ubii.dataStructure.Lists.StringList) type_;
      }
      return ubii.dataStructure.Lists.StringList.getDefaultInstance();
    }

    public static final int TOPIC_MUX_FIELD_NUMBER = 11;
    /**
     * <code>.ubii.devices.TopicMux topic_mux = 11;</code>
     */
    public boolean hasTopicMux() {
      return typeCase_ == 11;
    }
    /**
     * <code>.ubii.devices.TopicMux topic_mux = 11;</code>
     */
    public ubii.devices.TopicMuxOuterClass.TopicMux getTopicMux() {
      if (typeCase_ == 11) {
         return (ubii.devices.TopicMuxOuterClass.TopicMux) type_;
      }
      return ubii.devices.TopicMuxOuterClass.TopicMux.getDefaultInstance();
    }
    /**
     * <code>.ubii.devices.TopicMux topic_mux = 11;</code>
     */
    public ubii.devices.TopicMuxOuterClass.TopicMuxOrBuilder getTopicMuxOrBuilder() {
      if (typeCase_ == 11) {
         return (ubii.devices.TopicMuxOuterClass.TopicMux) type_;
      }
      return ubii.devices.TopicMuxOuterClass.TopicMux.getDefaultInstance();
    }

    public static final int TOPIC_MUX_LIST_FIELD_NUMBER = 12;
    /**
     * <code>.ubii.devices.TopicMuxList topic_mux_list = 12;</code>
     */
    public boolean hasTopicMuxList() {
      return typeCase_ == 12;
    }
    /**
     * <code>.ubii.devices.TopicMuxList topic_mux_list = 12;</code>
     */
    public ubii.devices.TopicMuxOuterClass.TopicMuxList getTopicMuxList() {
      if (typeCase_ == 12) {
         return (ubii.devices.TopicMuxOuterClass.TopicMuxList) type_;
      }
      return ubii.devices.TopicMuxOuterClass.TopicMuxList.getDefaultInstance();
    }
    /**
     * <code>.ubii.devices.TopicMuxList topic_mux_list = 12;</code>
     */
    public ubii.devices.TopicMuxOuterClass.TopicMuxListOrBuilder getTopicMuxListOrBuilder() {
      if (typeCase_ == 12) {
         return (ubii.devices.TopicMuxOuterClass.TopicMuxList) type_;
      }
      return ubii.devices.TopicMuxOuterClass.TopicMuxList.getDefaultInstance();
    }

    public static final int TOPIC_DEMUX_FIELD_NUMBER = 13;
    /**
     * <code>.ubii.devices.TopicDemux topic_demux = 13;</code>
     */
    public boolean hasTopicDemux() {
      return typeCase_ == 13;
    }
    /**
     * <code>.ubii.devices.TopicDemux topic_demux = 13;</code>
     */
    public ubii.devices.TopicDemuxOuterClass.TopicDemux getTopicDemux() {
      if (typeCase_ == 13) {
         return (ubii.devices.TopicDemuxOuterClass.TopicDemux) type_;
      }
      return ubii.devices.TopicDemuxOuterClass.TopicDemux.getDefaultInstance();
    }
    /**
     * <code>.ubii.devices.TopicDemux topic_demux = 13;</code>
     */
    public ubii.devices.TopicDemuxOuterClass.TopicDemuxOrBuilder getTopicDemuxOrBuilder() {
      if (typeCase_ == 13) {
         return (ubii.devices.TopicDemuxOuterClass.TopicDemux) type_;
      }
      return ubii.devices.TopicDemuxOuterClass.TopicDemux.getDefaultInstance();
    }

    public static final int TOPIC_DEMUX_LIST_FIELD_NUMBER = 14;
    /**
     * <code>.ubii.devices.TopicDemuxList topic_demux_list = 14;</code>
     */
    public boolean hasTopicDemuxList() {
      return typeCase_ == 14;
    }
    /**
     * <code>.ubii.devices.TopicDemuxList topic_demux_list = 14;</code>
     */
    public ubii.devices.TopicDemuxOuterClass.TopicDemuxList getTopicDemuxList() {
      if (typeCase_ == 14) {
         return (ubii.devices.TopicDemuxOuterClass.TopicDemuxList) type_;
      }
      return ubii.devices.TopicDemuxOuterClass.TopicDemuxList.getDefaultInstance();
    }
    /**
     * <code>.ubii.devices.TopicDemuxList topic_demux_list = 14;</code>
     */
    public ubii.devices.TopicDemuxOuterClass.TopicDemuxListOrBuilder getTopicDemuxListOrBuilder() {
      if (typeCase_ == 14) {
         return (ubii.devices.TopicDemuxOuterClass.TopicDemuxList) type_;
      }
      return ubii.devices.TopicDemuxOuterClass.TopicDemuxList.getDefaultInstance();
    }

    public static final int CLIENT_LIST_FIELD_NUMBER = 15;
    /**
     * <code>.ubii.clients.ClientList client_list = 15;</code>
     */
    public boolean hasClientList() {
      return typeCase_ == 15;
    }
    /**
     * <code>.ubii.clients.ClientList client_list = 15;</code>
     */
    public ubii.clients.ClientOuterClass.ClientList getClientList() {
      if (typeCase_ == 15) {
         return (ubii.clients.ClientOuterClass.ClientList) type_;
      }
      return ubii.clients.ClientOuterClass.ClientList.getDefaultInstance();
    }
    /**
     * <code>.ubii.clients.ClientList client_list = 15;</code>
     */
    public ubii.clients.ClientOuterClass.ClientListOrBuilder getClientListOrBuilder() {
      if (typeCase_ == 15) {
         return (ubii.clients.ClientOuterClass.ClientList) type_;
      }
      return ubii.clients.ClientOuterClass.ClientList.getDefaultInstance();
    }

    public static final int DEVICE_LIST_FIELD_NUMBER = 16;
    /**
     * <code>.ubii.devices.DeviceList device_list = 16;</code>
     */
    public boolean hasDeviceList() {
      return typeCase_ == 16;
    }
    /**
     * <code>.ubii.devices.DeviceList device_list = 16;</code>
     */
    public ubii.devices.DeviceOuterClass.DeviceList getDeviceList() {
      if (typeCase_ == 16) {
         return (ubii.devices.DeviceOuterClass.DeviceList) type_;
      }
      return ubii.devices.DeviceOuterClass.DeviceList.getDefaultInstance();
    }
    /**
     * <code>.ubii.devices.DeviceList device_list = 16;</code>
     */
    public ubii.devices.DeviceOuterClass.DeviceListOrBuilder getDeviceListOrBuilder() {
      if (typeCase_ == 16) {
         return (ubii.devices.DeviceOuterClass.DeviceList) type_;
      }
      return ubii.devices.DeviceOuterClass.DeviceList.getDefaultInstance();
    }

    public static final int SERVICE_FIELD_NUMBER = 17;
    /**
     * <code>.ubii.services.Service service = 17;</code>
     */
    public boolean hasService() {
      return typeCase_ == 17;
    }
    /**
     * <code>.ubii.services.Service service = 17;</code>
     */
    public ubii.services.ServiceOuterClass.Service getService() {
      if (typeCase_ == 17) {
         return (ubii.services.ServiceOuterClass.Service) type_;
      }
      return ubii.services.ServiceOuterClass.Service.getDefaultInstance();
    }
    /**
     * <code>.ubii.services.Service service = 17;</code>
     */
    public ubii.services.ServiceOuterClass.ServiceOrBuilder getServiceOrBuilder() {
      if (typeCase_ == 17) {
         return (ubii.services.ServiceOuterClass.Service) type_;
      }
      return ubii.services.ServiceOuterClass.Service.getDefaultInstance();
    }

    public static final int SERVICE_LIST_FIELD_NUMBER = 18;
    /**
     * <code>.ubii.services.ServiceList service_list = 18;</code>
     */
    public boolean hasServiceList() {
      return typeCase_ == 18;
    }
    /**
     * <code>.ubii.services.ServiceList service_list = 18;</code>
     */
    public ubii.services.ServiceOuterClass.ServiceList getServiceList() {
      if (typeCase_ == 18) {
         return (ubii.services.ServiceOuterClass.ServiceList) type_;
      }
      return ubii.services.ServiceOuterClass.ServiceList.getDefaultInstance();
    }
    /**
     * <code>.ubii.services.ServiceList service_list = 18;</code>
     */
    public ubii.services.ServiceOuterClass.ServiceListOrBuilder getServiceListOrBuilder() {
      if (typeCase_ == 18) {
         return (ubii.services.ServiceOuterClass.ServiceList) type_;
      }
      return ubii.services.ServiceOuterClass.ServiceList.getDefaultInstance();
    }

    public static final int LOCKSTEP_PROCESSING_REPLY_FIELD_NUMBER = 19;
    /**
     * <code>.ubii.processing.LockstepProcessingReply lockstep_processing_reply = 19;</code>
     */
    public boolean hasLockstepProcessingReply() {
      return typeCase_ == 19;
    }
    /**
     * <code>.ubii.processing.LockstepProcessingReply lockstep_processing_reply = 19;</code>
     */
    public ubii.processing.LockstepProcessing.LockstepProcessingReply getLockstepProcessingReply() {
      if (typeCase_ == 19) {
         return (ubii.processing.LockstepProcessing.LockstepProcessingReply) type_;
      }
      return ubii.processing.LockstepProcessing.LockstepProcessingReply.getDefaultInstance();
    }
    /**
     * <code>.ubii.processing.LockstepProcessingReply lockstep_processing_reply = 19;</code>
     */
    public ubii.processing.LockstepProcessing.LockstepProcessingReplyOrBuilder getLockstepProcessingReplyOrBuilder() {
      if (typeCase_ == 19) {
         return (ubii.processing.LockstepProcessing.LockstepProcessingReply) type_;
      }
      return ubii.processing.LockstepProcessing.LockstepProcessingReply.getDefaultInstance();
    }

    private byte memoizedIsInitialized = -1;
    @java.lang.Override
    public final boolean isInitialized() {
      byte isInitialized = memoizedIsInitialized;
      if (isInitialized == 1) return true;
      if (isInitialized == 0) return false;

      memoizedIsInitialized = 1;
      return true;
    }

    @java.lang.Override
    public void writeTo(com.google.protobuf.CodedOutputStream output)
                        throws java.io.IOException {
      if (typeCase_ == 1) {
        output.writeMessage(1, (ubii.general.SuccessOuterClass.Success) type_);
      }
      if (typeCase_ == 2) {
        output.writeMessage(2, (ubii.general.ErrorOuterClass.Error) type_);
      }
      if (typeCase_ == 3) {
        output.writeMessage(3, (ubii.clients.ClientOuterClass.Client) type_);
      }
      if (typeCase_ == 4) {
        output.writeMessage(4, (ubii.devices.DeviceOuterClass.Device) type_);
      }
      if (typeCase_ == 5) {
        output.writeMessage(5, (ubii.servers.ServerOuterClass.Server) type_);
      }
      if (typeCase_ == 6) {
        output.writeMessage(6, (ubii.sessions.SessionOuterClass.Session) type_);
      }
      if (typeCase_ == 7) {
        output.writeMessage(7, (ubii.sessions.SessionOuterClass.SessionList) type_);
      }
      if (typeCase_ == 8) {
        output.writeMessage(8, (ubii.processing.ProcessingModuleOuterClass.ProcessingModule) type_);
      }
      if (typeCase_ == 9) {
        output.writeMessage(9, (ubii.processing.ProcessingModuleOuterClass.ProcessingModuleList) type_);
      }
      if (typeCase_ == 10) {
        output.writeMessage(10, (ubii.dataStructure.Lists.StringList) type_);
      }
      if (typeCase_ == 11) {
        output.writeMessage(11, (ubii.devices.TopicMuxOuterClass.TopicMux) type_);
      }
      if (typeCase_ == 12) {
        output.writeMessage(12, (ubii.devices.TopicMuxOuterClass.TopicMuxList) type_);
      }
      if (typeCase_ == 13) {
        output.writeMessage(13, (ubii.devices.TopicDemuxOuterClass.TopicDemux) type_);
      }
      if (typeCase_ == 14) {
        output.writeMessage(14, (ubii.devices.TopicDemuxOuterClass.TopicDemuxList) type_);
      }
      if (typeCase_ == 15) {
        output.writeMessage(15, (ubii.clients.ClientOuterClass.ClientList) type_);
      }
      if (typeCase_ == 16) {
        output.writeMessage(16, (ubii.devices.DeviceOuterClass.DeviceList) type_);
      }
      if (typeCase_ == 17) {
        output.writeMessage(17, (ubii.services.ServiceOuterClass.Service) type_);
      }
      if (typeCase_ == 18) {
        output.writeMessage(18, (ubii.services.ServiceOuterClass.ServiceList) type_);
      }
      if (typeCase_ == 19) {
        output.writeMessage(19, (ubii.processing.LockstepProcessing.LockstepProcessingReply) type_);
      }
      unknownFields.writeTo(output);
    }

    @java.lang.Override
    public int getSerializedSize() {
      int size = memoizedSize;
      if (size != -1) return size;

      size = 0;
      if (typeCase_ == 1) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(1, (ubii.general.SuccessOuterClass.Success) type_);
      }
      if (typeCase_ == 2) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(2, (ubii.general.ErrorOuterClass.Error) type_);
      }
      if (typeCase_ == 3) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(3, (ubii.clients.ClientOuterClass.Client) type_);
      }
      if (typeCase_ == 4) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(4, (ubii.devices.DeviceOuterClass.Device) type_);
      }
      if (typeCase_ == 5) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(5, (ubii.servers.ServerOuterClass.Server) type_);
      }
      if (typeCase_ == 6) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(6, (ubii.sessions.SessionOuterClass.Session) type_);
      }
      if (typeCase_ == 7) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(7, (ubii.sessions.SessionOuterClass.SessionList) type_);
      }
      if (typeCase_ == 8) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(8, (ubii.processing.ProcessingModuleOuterClass.ProcessingModule) type_);
      }
      if (typeCase_ == 9) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(9, (ubii.processing.ProcessingModuleOuterClass.ProcessingModuleList) type_);
      }
      if (typeCase_ == 10) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(10, (ubii.dataStructure.Lists.StringList) type_);
      }
      if (typeCase_ == 11) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(11, (ubii.devices.TopicMuxOuterClass.TopicMux) type_);
      }
      if (typeCase_ == 12) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(12, (ubii.devices.TopicMuxOuterClass.TopicMuxList) type_);
      }
      if (typeCase_ == 13) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(13, (ubii.devices.TopicDemuxOuterClass.TopicDemux) type_);
      }
      if (typeCase_ == 14) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(14, (ubii.devices.TopicDemuxOuterClass.TopicDemuxList) type_);
      }
      if (typeCase_ == 15) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(15, (ubii.clients.ClientOuterClass.ClientList) type_);
      }
      if (typeCase_ == 16) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(16, (ubii.devices.DeviceOuterClass.DeviceList) type_);
      }
      if (typeCase_ == 17) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(17, (ubii.services.ServiceOuterClass.Service) type_);
      }
      if (typeCase_ == 18) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(18, (ubii.services.ServiceOuterClass.ServiceList) type_);
      }
      if (typeCase_ == 19) {
        size += com.google.protobuf.CodedOutputStream
          .computeMessageSize(19, (ubii.processing.LockstepProcessing.LockstepProcessingReply) type_);
      }
      size += unknownFields.getSerializedSize();
      memoizedSize = size;
      return size;
    }

    @java.lang.Override
    public boolean equals(final java.lang.Object obj) {
      if (obj == this) {
       return true;
      }
      if (!(obj instanceof ubii.services.ServiceReplyOuterClass.ServiceReply)) {
        return super.equals(obj);
      }
      ubii.services.ServiceReplyOuterClass.ServiceReply other = (ubii.services.ServiceReplyOuterClass.ServiceReply) obj;

      boolean result = true;
      result = result && getTypeCase().equals(
          other.getTypeCase());
      if (!result) return false;
      switch (typeCase_) {
        case 1:
          result = result && getSuccess()
              .equals(other.getSuccess());
          break;
        case 2:
          result = result && getError()
              .equals(other.getError());
          break;
        case 3:
          result = result && getClient()
              .equals(other.getClient());
          break;
        case 4:
          result = result && getDevice()
              .equals(other.getDevice());
          break;
        case 5:
          result = result && getServer()
              .equals(other.getServer());
          break;
        case 6:
          result = result && getSession()
              .equals(other.getSession());
          break;
        case 7:
          result = result && getSessionList()
              .equals(other.getSessionList());
          break;
        case 8:
          result = result && getProcessingModule()
              .equals(other.getProcessingModule());
          break;
        case 9:
          result = result && getProcessingModuleList()
              .equals(other.getProcessingModuleList());
          break;
        case 10:
          result = result && getStringList()
              .equals(other.getStringList());
          break;
        case 11:
          result = result && getTopicMux()
              .equals(other.getTopicMux());
          break;
        case 12:
          result = result && getTopicMuxList()
              .equals(other.getTopicMuxList());
          break;
        case 13:
          result = result && getTopicDemux()
              .equals(other.getTopicDemux());
          break;
        case 14:
          result = result && getTopicDemuxList()
              .equals(other.getTopicDemuxList());
          break;
        case 15:
          result = result && getClientList()
              .equals(other.getClientList());
          break;
        case 16:
          result = result && getDeviceList()
              .equals(other.getDeviceList());
          break;
        case 17:
          result = result && getService()
              .equals(other.getService());
          break;
        case 18:
          result = result && getServiceList()
              .equals(other.getServiceList());
          break;
        case 19:
          result = result && getLockstepProcessingReply()
              .equals(other.getLockstepProcessingReply());
          break;
        case 0:
        default:
      }
      result = result && unknownFields.equals(other.unknownFields);
      return result;
    }

    @java.lang.Override
    public int hashCode() {
      if (memoizedHashCode != 0) {
        return memoizedHashCode;
      }
      int hash = 41;
      hash = (19 * hash) + getDescriptor().hashCode();
      switch (typeCase_) {
        case 1:
          hash = (37 * hash) + SUCCESS_FIELD_NUMBER;
          hash = (53 * hash) + getSuccess().hashCode();
          break;
        case 2:
          hash = (37 * hash) + ERROR_FIELD_NUMBER;
          hash = (53 * hash) + getError().hashCode();
          break;
        case 3:
          hash = (37 * hash) + CLIENT_FIELD_NUMBER;
          hash = (53 * hash) + getClient().hashCode();
          break;
        case 4:
          hash = (37 * hash) + DEVICE_FIELD_NUMBER;
          hash = (53 * hash) + getDevice().hashCode();
          break;
        case 5:
          hash = (37 * hash) + SERVER_FIELD_NUMBER;
          hash = (53 * hash) + getServer().hashCode();
          break;
        case 6:
          hash = (37 * hash) + SESSION_FIELD_NUMBER;
          hash = (53 * hash) + getSession().hashCode();
          break;
        case 7:
          hash = (37 * hash) + SESSION_LIST_FIELD_NUMBER;
          hash = (53 * hash) + getSessionList().hashCode();
          break;
        case 8:
          hash = (37 * hash) + PROCESSING_MODULE_FIELD_NUMBER;
          hash = (53 * hash) + getProcessingModule().hashCode();
          break;
        case 9:
          hash = (37 * hash) + PROCESSING_MODULE_LIST_FIELD_NUMBER;
          hash = (53 * hash) + getProcessingModuleList().hashCode();
          break;
        case 10:
          hash = (37 * hash) + STRING_LIST_FIELD_NUMBER;
          hash = (53 * hash) + getStringList().hashCode();
          break;
        case 11:
          hash = (37 * hash) + TOPIC_MUX_FIELD_NUMBER;
          hash = (53 * hash) + getTopicMux().hashCode();
          break;
        case 12:
          hash = (37 * hash) + TOPIC_MUX_LIST_FIELD_NUMBER;
          hash = (53 * hash) + getTopicMuxList().hashCode();
          break;
        case 13:
          hash = (37 * hash) + TOPIC_DEMUX_FIELD_NUMBER;
          hash = (53 * hash) + getTopicDemux().hashCode();
          break;
        case 14:
          hash = (37 * hash) + TOPIC_DEMUX_LIST_FIELD_NUMBER;
          hash = (53 * hash) + getTopicDemuxList().hashCode();
          break;
        case 15:
          hash = (37 * hash) + CLIENT_LIST_FIELD_NUMBER;
          hash = (53 * hash) + getClientList().hashCode();
          break;
        case 16:
          hash = (37 * hash) + DEVICE_LIST_FIELD_NUMBER;
          hash = (53 * hash) + getDeviceList().hashCode();
          break;
        case 17:
          hash = (37 * hash) + SERVICE_FIELD_NUMBER;
          hash = (53 * hash) + getService().hashCode();
          break;
        case 18:
          hash = (37 * hash) + SERVICE_LIST_FIELD_NUMBER;
          hash = (53 * hash) + getServiceList().hashCode();
          break;
        case 19:
          hash = (37 * hash) + LOCKSTEP_PROCESSING_REPLY_FIELD_NUMBER;
          hash = (53 * hash) + getLockstepProcessingReply().hashCode();
          break;
        case 0:
        default:
      }
      hash = (29 * hash) + unknownFields.hashCode();
      memoizedHashCode = hash;
      return hash;
    }

    public static ubii.services.ServiceReplyOuterClass.ServiceReply parseFrom(
        java.nio.ByteBuffer data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.services.ServiceReplyOuterClass.ServiceReply parseFrom(
        java.nio.ByteBuffer data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.services.ServiceReplyOuterClass.ServiceReply parseFrom(
        com.google.protobuf.ByteString data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.services.ServiceReplyOuterClass.ServiceReply parseFrom(
        com.google.protobuf.ByteString data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.services.ServiceReplyOuterClass.ServiceReply parseFrom(byte[] data)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data);
    }
    public static ubii.services.ServiceReplyOuterClass.ServiceReply parseFrom(
        byte[] data,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws com.google.protobuf.InvalidProtocolBufferException {
      return PARSER.parseFrom(data, extensionRegistry);
    }
    public static ubii.services.ServiceReplyOuterClass.ServiceReply parseFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.services.ServiceReplyOuterClass.ServiceReply parseFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.services.ServiceReplyOuterClass.ServiceReply parseDelimitedFrom(java.io.InputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input);
    }
    public static ubii.services.ServiceReplyOuterClass.ServiceReply parseDelimitedFrom(
        java.io.InputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseDelimitedWithIOException(PARSER, input, extensionRegistry);
    }
    public static ubii.services.ServiceReplyOuterClass.ServiceReply parseFrom(
        com.google.protobuf.CodedInputStream input)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input);
    }
    public static ubii.services.ServiceReplyOuterClass.ServiceReply parseFrom(
        com.google.protobuf.CodedInputStream input,
        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
        throws java.io.IOException {
      return com.google.protobuf.GeneratedMessageV3
          .parseWithIOException(PARSER, input, extensionRegistry);
    }

    @java.lang.Override
    public Builder newBuilderForType() { return newBuilder(); }
    public static Builder newBuilder() {
      return DEFAULT_INSTANCE.toBuilder();
    }
    public static Builder newBuilder(ubii.services.ServiceReplyOuterClass.ServiceReply prototype) {
      return DEFAULT_INSTANCE.toBuilder().mergeFrom(prototype);
    }
    @java.lang.Override
    public Builder toBuilder() {
      return this == DEFAULT_INSTANCE
          ? new Builder() : new Builder().mergeFrom(this);
    }

    @java.lang.Override
    protected Builder newBuilderForType(
        com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
      Builder builder = new Builder(parent);
      return builder;
    }
    /**
     * Protobuf type {@code ubii.services.ServiceReply}
     */
    public static final class Builder extends
        com.google.protobuf.GeneratedMessageV3.Builder<Builder> implements
        // @@protoc_insertion_point(builder_implements:ubii.services.ServiceReply)
        ubii.services.ServiceReplyOuterClass.ServiceReplyOrBuilder {
      public static final com.google.protobuf.Descriptors.Descriptor
          getDescriptor() {
        return ubii.services.ServiceReplyOuterClass.internal_static_ubii_services_ServiceReply_descriptor;
      }

      @java.lang.Override
      protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
          internalGetFieldAccessorTable() {
        return ubii.services.ServiceReplyOuterClass.internal_static_ubii_services_ServiceReply_fieldAccessorTable
            .ensureFieldAccessorsInitialized(
                ubii.services.ServiceReplyOuterClass.ServiceReply.class, ubii.services.ServiceReplyOuterClass.ServiceReply.Builder.class);
      }

      // Construct using ubii.services.ServiceReplyOuterClass.ServiceReply.newBuilder()
      private Builder() {
        maybeForceBuilderInitialization();
      }

      private Builder(
          com.google.protobuf.GeneratedMessageV3.BuilderParent parent) {
        super(parent);
        maybeForceBuilderInitialization();
      }
      private void maybeForceBuilderInitialization() {
        if (com.google.protobuf.GeneratedMessageV3
                .alwaysUseFieldBuilders) {
        }
      }
      @java.lang.Override
      public Builder clear() {
        super.clear();
        typeCase_ = 0;
        type_ = null;
        return this;
      }

      @java.lang.Override
      public com.google.protobuf.Descriptors.Descriptor
          getDescriptorForType() {
        return ubii.services.ServiceReplyOuterClass.internal_static_ubii_services_ServiceReply_descriptor;
      }

      @java.lang.Override
      public ubii.services.ServiceReplyOuterClass.ServiceReply getDefaultInstanceForType() {
        return ubii.services.ServiceReplyOuterClass.ServiceReply.getDefaultInstance();
      }

      @java.lang.Override
      public ubii.services.ServiceReplyOuterClass.ServiceReply build() {
        ubii.services.ServiceReplyOuterClass.ServiceReply result = buildPartial();
        if (!result.isInitialized()) {
          throw newUninitializedMessageException(result);
        }
        return result;
      }

      @java.lang.Override
      public ubii.services.ServiceReplyOuterClass.ServiceReply buildPartial() {
        ubii.services.ServiceReplyOuterClass.ServiceReply result = new ubii.services.ServiceReplyOuterClass.ServiceReply(this);
        if (typeCase_ == 1) {
          if (successBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = successBuilder_.build();
          }
        }
        if (typeCase_ == 2) {
          if (errorBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = errorBuilder_.build();
          }
        }
        if (typeCase_ == 3) {
          if (clientBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = clientBuilder_.build();
          }
        }
        if (typeCase_ == 4) {
          if (deviceBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = deviceBuilder_.build();
          }
        }
        if (typeCase_ == 5) {
          if (serverBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = serverBuilder_.build();
          }
        }
        if (typeCase_ == 6) {
          if (sessionBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = sessionBuilder_.build();
          }
        }
        if (typeCase_ == 7) {
          if (sessionListBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = sessionListBuilder_.build();
          }
        }
        if (typeCase_ == 8) {
          if (processingModuleBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = processingModuleBuilder_.build();
          }
        }
        if (typeCase_ == 9) {
          if (processingModuleListBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = processingModuleListBuilder_.build();
          }
        }
        if (typeCase_ == 10) {
          if (stringListBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = stringListBuilder_.build();
          }
        }
        if (typeCase_ == 11) {
          if (topicMuxBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = topicMuxBuilder_.build();
          }
        }
        if (typeCase_ == 12) {
          if (topicMuxListBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = topicMuxListBuilder_.build();
          }
        }
        if (typeCase_ == 13) {
          if (topicDemuxBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = topicDemuxBuilder_.build();
          }
        }
        if (typeCase_ == 14) {
          if (topicDemuxListBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = topicDemuxListBuilder_.build();
          }
        }
        if (typeCase_ == 15) {
          if (clientListBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = clientListBuilder_.build();
          }
        }
        if (typeCase_ == 16) {
          if (deviceListBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = deviceListBuilder_.build();
          }
        }
        if (typeCase_ == 17) {
          if (serviceBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = serviceBuilder_.build();
          }
        }
        if (typeCase_ == 18) {
          if (serviceListBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = serviceListBuilder_.build();
          }
        }
        if (typeCase_ == 19) {
          if (lockstepProcessingReplyBuilder_ == null) {
            result.type_ = type_;
          } else {
            result.type_ = lockstepProcessingReplyBuilder_.build();
          }
        }
        result.typeCase_ = typeCase_;
        onBuilt();
        return result;
      }

      @java.lang.Override
      public Builder clone() {
        return (Builder) super.clone();
      }
      @java.lang.Override
      public Builder setField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.setField(field, value);
      }
      @java.lang.Override
      public Builder clearField(
          com.google.protobuf.Descriptors.FieldDescriptor field) {
        return (Builder) super.clearField(field);
      }
      @java.lang.Override
      public Builder clearOneof(
          com.google.protobuf.Descriptors.OneofDescriptor oneof) {
        return (Builder) super.clearOneof(oneof);
      }
      @java.lang.Override
      public Builder setRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          int index, java.lang.Object value) {
        return (Builder) super.setRepeatedField(field, index, value);
      }
      @java.lang.Override
      public Builder addRepeatedField(
          com.google.protobuf.Descriptors.FieldDescriptor field,
          java.lang.Object value) {
        return (Builder) super.addRepeatedField(field, value);
      }
      @java.lang.Override
      public Builder mergeFrom(com.google.protobuf.Message other) {
        if (other instanceof ubii.services.ServiceReplyOuterClass.ServiceReply) {
          return mergeFrom((ubii.services.ServiceReplyOuterClass.ServiceReply)other);
        } else {
          super.mergeFrom(other);
          return this;
        }
      }

      public Builder mergeFrom(ubii.services.ServiceReplyOuterClass.ServiceReply other) {
        if (other == ubii.services.ServiceReplyOuterClass.ServiceReply.getDefaultInstance()) return this;
        switch (other.getTypeCase()) {
          case SUCCESS: {
            mergeSuccess(other.getSuccess());
            break;
          }
          case ERROR: {
            mergeError(other.getError());
            break;
          }
          case CLIENT: {
            mergeClient(other.getClient());
            break;
          }
          case DEVICE: {
            mergeDevice(other.getDevice());
            break;
          }
          case SERVER: {
            mergeServer(other.getServer());
            break;
          }
          case SESSION: {
            mergeSession(other.getSession());
            break;
          }
          case SESSION_LIST: {
            mergeSessionList(other.getSessionList());
            break;
          }
          case PROCESSING_MODULE: {
            mergeProcessingModule(other.getProcessingModule());
            break;
          }
          case PROCESSING_MODULE_LIST: {
            mergeProcessingModuleList(other.getProcessingModuleList());
            break;
          }
          case STRING_LIST: {
            mergeStringList(other.getStringList());
            break;
          }
          case TOPIC_MUX: {
            mergeTopicMux(other.getTopicMux());
            break;
          }
          case TOPIC_MUX_LIST: {
            mergeTopicMuxList(other.getTopicMuxList());
            break;
          }
          case TOPIC_DEMUX: {
            mergeTopicDemux(other.getTopicDemux());
            break;
          }
          case TOPIC_DEMUX_LIST: {
            mergeTopicDemuxList(other.getTopicDemuxList());
            break;
          }
          case CLIENT_LIST: {
            mergeClientList(other.getClientList());
            break;
          }
          case DEVICE_LIST: {
            mergeDeviceList(other.getDeviceList());
            break;
          }
          case SERVICE: {
            mergeService(other.getService());
            break;
          }
          case SERVICE_LIST: {
            mergeServiceList(other.getServiceList());
            break;
          }
          case LOCKSTEP_PROCESSING_REPLY: {
            mergeLockstepProcessingReply(other.getLockstepProcessingReply());
            break;
          }
          case TYPE_NOT_SET: {
            break;
          }
        }
        this.mergeUnknownFields(other.unknownFields);
        onChanged();
        return this;
      }

      @java.lang.Override
      public final boolean isInitialized() {
        return true;
      }

      @java.lang.Override
      public Builder mergeFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws java.io.IOException {
        ubii.services.ServiceReplyOuterClass.ServiceReply parsedMessage = null;
        try {
          parsedMessage = PARSER.parsePartialFrom(input, extensionRegistry);
        } catch (com.google.protobuf.InvalidProtocolBufferException e) {
          parsedMessage = (ubii.services.ServiceReplyOuterClass.ServiceReply) e.getUnfinishedMessage();
          throw e.unwrapIOException();
        } finally {
          if (parsedMessage != null) {
            mergeFrom(parsedMessage);
          }
        }
        return this;
      }
      private int typeCase_ = 0;
      private java.lang.Object type_;
      public TypeCase
          getTypeCase() {
        return TypeCase.forNumber(
            typeCase_);
      }

      public Builder clearType() {
        typeCase_ = 0;
        type_ = null;
        onChanged();
        return this;
      }


      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.general.SuccessOuterClass.Success, ubii.general.SuccessOuterClass.Success.Builder, ubii.general.SuccessOuterClass.SuccessOrBuilder> successBuilder_;
      /**
       * <code>.ubii.general.Success success = 1;</code>
       */
      public boolean hasSuccess() {
        return typeCase_ == 1;
      }
      /**
       * <code>.ubii.general.Success success = 1;</code>
       */
      public ubii.general.SuccessOuterClass.Success getSuccess() {
        if (successBuilder_ == null) {
          if (typeCase_ == 1) {
            return (ubii.general.SuccessOuterClass.Success) type_;
          }
          return ubii.general.SuccessOuterClass.Success.getDefaultInstance();
        } else {
          if (typeCase_ == 1) {
            return successBuilder_.getMessage();
          }
          return ubii.general.SuccessOuterClass.Success.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.general.Success success = 1;</code>
       */
      public Builder setSuccess(ubii.general.SuccessOuterClass.Success value) {
        if (successBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          successBuilder_.setMessage(value);
        }
        typeCase_ = 1;
        return this;
      }
      /**
       * <code>.ubii.general.Success success = 1;</code>
       */
      public Builder setSuccess(
          ubii.general.SuccessOuterClass.Success.Builder builderForValue) {
        if (successBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          successBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 1;
        return this;
      }
      /**
       * <code>.ubii.general.Success success = 1;</code>
       */
      public Builder mergeSuccess(ubii.general.SuccessOuterClass.Success value) {
        if (successBuilder_ == null) {
          if (typeCase_ == 1 &&
              type_ != ubii.general.SuccessOuterClass.Success.getDefaultInstance()) {
            type_ = ubii.general.SuccessOuterClass.Success.newBuilder((ubii.general.SuccessOuterClass.Success) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 1) {
            successBuilder_.mergeFrom(value);
          }
          successBuilder_.setMessage(value);
        }
        typeCase_ = 1;
        return this;
      }
      /**
       * <code>.ubii.general.Success success = 1;</code>
       */
      public Builder clearSuccess() {
        if (successBuilder_ == null) {
          if (typeCase_ == 1) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 1) {
            typeCase_ = 0;
            type_ = null;
          }
          successBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.general.Success success = 1;</code>
       */
      public ubii.general.SuccessOuterClass.Success.Builder getSuccessBuilder() {
        return getSuccessFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.general.Success success = 1;</code>
       */
      public ubii.general.SuccessOuterClass.SuccessOrBuilder getSuccessOrBuilder() {
        if ((typeCase_ == 1) && (successBuilder_ != null)) {
          return successBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 1) {
            return (ubii.general.SuccessOuterClass.Success) type_;
          }
          return ubii.general.SuccessOuterClass.Success.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.general.Success success = 1;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.general.SuccessOuterClass.Success, ubii.general.SuccessOuterClass.Success.Builder, ubii.general.SuccessOuterClass.SuccessOrBuilder> 
          getSuccessFieldBuilder() {
        if (successBuilder_ == null) {
          if (!(typeCase_ == 1)) {
            type_ = ubii.general.SuccessOuterClass.Success.getDefaultInstance();
          }
          successBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.general.SuccessOuterClass.Success, ubii.general.SuccessOuterClass.Success.Builder, ubii.general.SuccessOuterClass.SuccessOrBuilder>(
                  (ubii.general.SuccessOuterClass.Success) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 1;
        onChanged();;
        return successBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.general.ErrorOuterClass.Error, ubii.general.ErrorOuterClass.Error.Builder, ubii.general.ErrorOuterClass.ErrorOrBuilder> errorBuilder_;
      /**
       * <code>.ubii.general.Error error = 2;</code>
       */
      public boolean hasError() {
        return typeCase_ == 2;
      }
      /**
       * <code>.ubii.general.Error error = 2;</code>
       */
      public ubii.general.ErrorOuterClass.Error getError() {
        if (errorBuilder_ == null) {
          if (typeCase_ == 2) {
            return (ubii.general.ErrorOuterClass.Error) type_;
          }
          return ubii.general.ErrorOuterClass.Error.getDefaultInstance();
        } else {
          if (typeCase_ == 2) {
            return errorBuilder_.getMessage();
          }
          return ubii.general.ErrorOuterClass.Error.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.general.Error error = 2;</code>
       */
      public Builder setError(ubii.general.ErrorOuterClass.Error value) {
        if (errorBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          errorBuilder_.setMessage(value);
        }
        typeCase_ = 2;
        return this;
      }
      /**
       * <code>.ubii.general.Error error = 2;</code>
       */
      public Builder setError(
          ubii.general.ErrorOuterClass.Error.Builder builderForValue) {
        if (errorBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          errorBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 2;
        return this;
      }
      /**
       * <code>.ubii.general.Error error = 2;</code>
       */
      public Builder mergeError(ubii.general.ErrorOuterClass.Error value) {
        if (errorBuilder_ == null) {
          if (typeCase_ == 2 &&
              type_ != ubii.general.ErrorOuterClass.Error.getDefaultInstance()) {
            type_ = ubii.general.ErrorOuterClass.Error.newBuilder((ubii.general.ErrorOuterClass.Error) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 2) {
            errorBuilder_.mergeFrom(value);
          }
          errorBuilder_.setMessage(value);
        }
        typeCase_ = 2;
        return this;
      }
      /**
       * <code>.ubii.general.Error error = 2;</code>
       */
      public Builder clearError() {
        if (errorBuilder_ == null) {
          if (typeCase_ == 2) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 2) {
            typeCase_ = 0;
            type_ = null;
          }
          errorBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.general.Error error = 2;</code>
       */
      public ubii.general.ErrorOuterClass.Error.Builder getErrorBuilder() {
        return getErrorFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.general.Error error = 2;</code>
       */
      public ubii.general.ErrorOuterClass.ErrorOrBuilder getErrorOrBuilder() {
        if ((typeCase_ == 2) && (errorBuilder_ != null)) {
          return errorBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 2) {
            return (ubii.general.ErrorOuterClass.Error) type_;
          }
          return ubii.general.ErrorOuterClass.Error.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.general.Error error = 2;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.general.ErrorOuterClass.Error, ubii.general.ErrorOuterClass.Error.Builder, ubii.general.ErrorOuterClass.ErrorOrBuilder> 
          getErrorFieldBuilder() {
        if (errorBuilder_ == null) {
          if (!(typeCase_ == 2)) {
            type_ = ubii.general.ErrorOuterClass.Error.getDefaultInstance();
          }
          errorBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.general.ErrorOuterClass.Error, ubii.general.ErrorOuterClass.Error.Builder, ubii.general.ErrorOuterClass.ErrorOrBuilder>(
                  (ubii.general.ErrorOuterClass.Error) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 2;
        onChanged();;
        return errorBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.clients.ClientOuterClass.Client, ubii.clients.ClientOuterClass.Client.Builder, ubii.clients.ClientOuterClass.ClientOrBuilder> clientBuilder_;
      /**
       * <code>.ubii.clients.Client client = 3;</code>
       */
      public boolean hasClient() {
        return typeCase_ == 3;
      }
      /**
       * <code>.ubii.clients.Client client = 3;</code>
       */
      public ubii.clients.ClientOuterClass.Client getClient() {
        if (clientBuilder_ == null) {
          if (typeCase_ == 3) {
            return (ubii.clients.ClientOuterClass.Client) type_;
          }
          return ubii.clients.ClientOuterClass.Client.getDefaultInstance();
        } else {
          if (typeCase_ == 3) {
            return clientBuilder_.getMessage();
          }
          return ubii.clients.ClientOuterClass.Client.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.clients.Client client = 3;</code>
       */
      public Builder setClient(ubii.clients.ClientOuterClass.Client value) {
        if (clientBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          clientBuilder_.setMessage(value);
        }
        typeCase_ = 3;
        return this;
      }
      /**
       * <code>.ubii.clients.Client client = 3;</code>
       */
      public Builder setClient(
          ubii.clients.ClientOuterClass.Client.Builder builderForValue) {
        if (clientBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          clientBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 3;
        return this;
      }
      /**
       * <code>.ubii.clients.Client client = 3;</code>
       */
      public Builder mergeClient(ubii.clients.ClientOuterClass.Client value) {
        if (clientBuilder_ == null) {
          if (typeCase_ == 3 &&
              type_ != ubii.clients.ClientOuterClass.Client.getDefaultInstance()) {
            type_ = ubii.clients.ClientOuterClass.Client.newBuilder((ubii.clients.ClientOuterClass.Client) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 3) {
            clientBuilder_.mergeFrom(value);
          }
          clientBuilder_.setMessage(value);
        }
        typeCase_ = 3;
        return this;
      }
      /**
       * <code>.ubii.clients.Client client = 3;</code>
       */
      public Builder clearClient() {
        if (clientBuilder_ == null) {
          if (typeCase_ == 3) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 3) {
            typeCase_ = 0;
            type_ = null;
          }
          clientBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.clients.Client client = 3;</code>
       */
      public ubii.clients.ClientOuterClass.Client.Builder getClientBuilder() {
        return getClientFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.clients.Client client = 3;</code>
       */
      public ubii.clients.ClientOuterClass.ClientOrBuilder getClientOrBuilder() {
        if ((typeCase_ == 3) && (clientBuilder_ != null)) {
          return clientBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 3) {
            return (ubii.clients.ClientOuterClass.Client) type_;
          }
          return ubii.clients.ClientOuterClass.Client.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.clients.Client client = 3;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.clients.ClientOuterClass.Client, ubii.clients.ClientOuterClass.Client.Builder, ubii.clients.ClientOuterClass.ClientOrBuilder> 
          getClientFieldBuilder() {
        if (clientBuilder_ == null) {
          if (!(typeCase_ == 3)) {
            type_ = ubii.clients.ClientOuterClass.Client.getDefaultInstance();
          }
          clientBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.clients.ClientOuterClass.Client, ubii.clients.ClientOuterClass.Client.Builder, ubii.clients.ClientOuterClass.ClientOrBuilder>(
                  (ubii.clients.ClientOuterClass.Client) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 3;
        onChanged();;
        return clientBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.devices.DeviceOuterClass.Device, ubii.devices.DeviceOuterClass.Device.Builder, ubii.devices.DeviceOuterClass.DeviceOrBuilder> deviceBuilder_;
      /**
       * <code>.ubii.devices.Device device = 4;</code>
       */
      public boolean hasDevice() {
        return typeCase_ == 4;
      }
      /**
       * <code>.ubii.devices.Device device = 4;</code>
       */
      public ubii.devices.DeviceOuterClass.Device getDevice() {
        if (deviceBuilder_ == null) {
          if (typeCase_ == 4) {
            return (ubii.devices.DeviceOuterClass.Device) type_;
          }
          return ubii.devices.DeviceOuterClass.Device.getDefaultInstance();
        } else {
          if (typeCase_ == 4) {
            return deviceBuilder_.getMessage();
          }
          return ubii.devices.DeviceOuterClass.Device.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.devices.Device device = 4;</code>
       */
      public Builder setDevice(ubii.devices.DeviceOuterClass.Device value) {
        if (deviceBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          deviceBuilder_.setMessage(value);
        }
        typeCase_ = 4;
        return this;
      }
      /**
       * <code>.ubii.devices.Device device = 4;</code>
       */
      public Builder setDevice(
          ubii.devices.DeviceOuterClass.Device.Builder builderForValue) {
        if (deviceBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          deviceBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 4;
        return this;
      }
      /**
       * <code>.ubii.devices.Device device = 4;</code>
       */
      public Builder mergeDevice(ubii.devices.DeviceOuterClass.Device value) {
        if (deviceBuilder_ == null) {
          if (typeCase_ == 4 &&
              type_ != ubii.devices.DeviceOuterClass.Device.getDefaultInstance()) {
            type_ = ubii.devices.DeviceOuterClass.Device.newBuilder((ubii.devices.DeviceOuterClass.Device) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 4) {
            deviceBuilder_.mergeFrom(value);
          }
          deviceBuilder_.setMessage(value);
        }
        typeCase_ = 4;
        return this;
      }
      /**
       * <code>.ubii.devices.Device device = 4;</code>
       */
      public Builder clearDevice() {
        if (deviceBuilder_ == null) {
          if (typeCase_ == 4) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 4) {
            typeCase_ = 0;
            type_ = null;
          }
          deviceBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.devices.Device device = 4;</code>
       */
      public ubii.devices.DeviceOuterClass.Device.Builder getDeviceBuilder() {
        return getDeviceFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.devices.Device device = 4;</code>
       */
      public ubii.devices.DeviceOuterClass.DeviceOrBuilder getDeviceOrBuilder() {
        if ((typeCase_ == 4) && (deviceBuilder_ != null)) {
          return deviceBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 4) {
            return (ubii.devices.DeviceOuterClass.Device) type_;
          }
          return ubii.devices.DeviceOuterClass.Device.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.devices.Device device = 4;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.devices.DeviceOuterClass.Device, ubii.devices.DeviceOuterClass.Device.Builder, ubii.devices.DeviceOuterClass.DeviceOrBuilder> 
          getDeviceFieldBuilder() {
        if (deviceBuilder_ == null) {
          if (!(typeCase_ == 4)) {
            type_ = ubii.devices.DeviceOuterClass.Device.getDefaultInstance();
          }
          deviceBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.devices.DeviceOuterClass.Device, ubii.devices.DeviceOuterClass.Device.Builder, ubii.devices.DeviceOuterClass.DeviceOrBuilder>(
                  (ubii.devices.DeviceOuterClass.Device) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 4;
        onChanged();;
        return deviceBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.servers.ServerOuterClass.Server, ubii.servers.ServerOuterClass.Server.Builder, ubii.servers.ServerOuterClass.ServerOrBuilder> serverBuilder_;
      /**
       * <code>.ubii.servers.Server server = 5;</code>
       */
      public boolean hasServer() {
        return typeCase_ == 5;
      }
      /**
       * <code>.ubii.servers.Server server = 5;</code>
       */
      public ubii.servers.ServerOuterClass.Server getServer() {
        if (serverBuilder_ == null) {
          if (typeCase_ == 5) {
            return (ubii.servers.ServerOuterClass.Server) type_;
          }
          return ubii.servers.ServerOuterClass.Server.getDefaultInstance();
        } else {
          if (typeCase_ == 5) {
            return serverBuilder_.getMessage();
          }
          return ubii.servers.ServerOuterClass.Server.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.servers.Server server = 5;</code>
       */
      public Builder setServer(ubii.servers.ServerOuterClass.Server value) {
        if (serverBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          serverBuilder_.setMessage(value);
        }
        typeCase_ = 5;
        return this;
      }
      /**
       * <code>.ubii.servers.Server server = 5;</code>
       */
      public Builder setServer(
          ubii.servers.ServerOuterClass.Server.Builder builderForValue) {
        if (serverBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          serverBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 5;
        return this;
      }
      /**
       * <code>.ubii.servers.Server server = 5;</code>
       */
      public Builder mergeServer(ubii.servers.ServerOuterClass.Server value) {
        if (serverBuilder_ == null) {
          if (typeCase_ == 5 &&
              type_ != ubii.servers.ServerOuterClass.Server.getDefaultInstance()) {
            type_ = ubii.servers.ServerOuterClass.Server.newBuilder((ubii.servers.ServerOuterClass.Server) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 5) {
            serverBuilder_.mergeFrom(value);
          }
          serverBuilder_.setMessage(value);
        }
        typeCase_ = 5;
        return this;
      }
      /**
       * <code>.ubii.servers.Server server = 5;</code>
       */
      public Builder clearServer() {
        if (serverBuilder_ == null) {
          if (typeCase_ == 5) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 5) {
            typeCase_ = 0;
            type_ = null;
          }
          serverBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.servers.Server server = 5;</code>
       */
      public ubii.servers.ServerOuterClass.Server.Builder getServerBuilder() {
        return getServerFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.servers.Server server = 5;</code>
       */
      public ubii.servers.ServerOuterClass.ServerOrBuilder getServerOrBuilder() {
        if ((typeCase_ == 5) && (serverBuilder_ != null)) {
          return serverBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 5) {
            return (ubii.servers.ServerOuterClass.Server) type_;
          }
          return ubii.servers.ServerOuterClass.Server.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.servers.Server server = 5;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.servers.ServerOuterClass.Server, ubii.servers.ServerOuterClass.Server.Builder, ubii.servers.ServerOuterClass.ServerOrBuilder> 
          getServerFieldBuilder() {
        if (serverBuilder_ == null) {
          if (!(typeCase_ == 5)) {
            type_ = ubii.servers.ServerOuterClass.Server.getDefaultInstance();
          }
          serverBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.servers.ServerOuterClass.Server, ubii.servers.ServerOuterClass.Server.Builder, ubii.servers.ServerOuterClass.ServerOrBuilder>(
                  (ubii.servers.ServerOuterClass.Server) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 5;
        onChanged();;
        return serverBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.sessions.SessionOuterClass.Session, ubii.sessions.SessionOuterClass.Session.Builder, ubii.sessions.SessionOuterClass.SessionOrBuilder> sessionBuilder_;
      /**
       * <code>.ubii.sessions.Session session = 6;</code>
       */
      public boolean hasSession() {
        return typeCase_ == 6;
      }
      /**
       * <code>.ubii.sessions.Session session = 6;</code>
       */
      public ubii.sessions.SessionOuterClass.Session getSession() {
        if (sessionBuilder_ == null) {
          if (typeCase_ == 6) {
            return (ubii.sessions.SessionOuterClass.Session) type_;
          }
          return ubii.sessions.SessionOuterClass.Session.getDefaultInstance();
        } else {
          if (typeCase_ == 6) {
            return sessionBuilder_.getMessage();
          }
          return ubii.sessions.SessionOuterClass.Session.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.sessions.Session session = 6;</code>
       */
      public Builder setSession(ubii.sessions.SessionOuterClass.Session value) {
        if (sessionBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          sessionBuilder_.setMessage(value);
        }
        typeCase_ = 6;
        return this;
      }
      /**
       * <code>.ubii.sessions.Session session = 6;</code>
       */
      public Builder setSession(
          ubii.sessions.SessionOuterClass.Session.Builder builderForValue) {
        if (sessionBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          sessionBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 6;
        return this;
      }
      /**
       * <code>.ubii.sessions.Session session = 6;</code>
       */
      public Builder mergeSession(ubii.sessions.SessionOuterClass.Session value) {
        if (sessionBuilder_ == null) {
          if (typeCase_ == 6 &&
              type_ != ubii.sessions.SessionOuterClass.Session.getDefaultInstance()) {
            type_ = ubii.sessions.SessionOuterClass.Session.newBuilder((ubii.sessions.SessionOuterClass.Session) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 6) {
            sessionBuilder_.mergeFrom(value);
          }
          sessionBuilder_.setMessage(value);
        }
        typeCase_ = 6;
        return this;
      }
      /**
       * <code>.ubii.sessions.Session session = 6;</code>
       */
      public Builder clearSession() {
        if (sessionBuilder_ == null) {
          if (typeCase_ == 6) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 6) {
            typeCase_ = 0;
            type_ = null;
          }
          sessionBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.sessions.Session session = 6;</code>
       */
      public ubii.sessions.SessionOuterClass.Session.Builder getSessionBuilder() {
        return getSessionFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.sessions.Session session = 6;</code>
       */
      public ubii.sessions.SessionOuterClass.SessionOrBuilder getSessionOrBuilder() {
        if ((typeCase_ == 6) && (sessionBuilder_ != null)) {
          return sessionBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 6) {
            return (ubii.sessions.SessionOuterClass.Session) type_;
          }
          return ubii.sessions.SessionOuterClass.Session.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.sessions.Session session = 6;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.sessions.SessionOuterClass.Session, ubii.sessions.SessionOuterClass.Session.Builder, ubii.sessions.SessionOuterClass.SessionOrBuilder> 
          getSessionFieldBuilder() {
        if (sessionBuilder_ == null) {
          if (!(typeCase_ == 6)) {
            type_ = ubii.sessions.SessionOuterClass.Session.getDefaultInstance();
          }
          sessionBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.sessions.SessionOuterClass.Session, ubii.sessions.SessionOuterClass.Session.Builder, ubii.sessions.SessionOuterClass.SessionOrBuilder>(
                  (ubii.sessions.SessionOuterClass.Session) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 6;
        onChanged();;
        return sessionBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.sessions.SessionOuterClass.SessionList, ubii.sessions.SessionOuterClass.SessionList.Builder, ubii.sessions.SessionOuterClass.SessionListOrBuilder> sessionListBuilder_;
      /**
       * <code>.ubii.sessions.SessionList session_list = 7;</code>
       */
      public boolean hasSessionList() {
        return typeCase_ == 7;
      }
      /**
       * <code>.ubii.sessions.SessionList session_list = 7;</code>
       */
      public ubii.sessions.SessionOuterClass.SessionList getSessionList() {
        if (sessionListBuilder_ == null) {
          if (typeCase_ == 7) {
            return (ubii.sessions.SessionOuterClass.SessionList) type_;
          }
          return ubii.sessions.SessionOuterClass.SessionList.getDefaultInstance();
        } else {
          if (typeCase_ == 7) {
            return sessionListBuilder_.getMessage();
          }
          return ubii.sessions.SessionOuterClass.SessionList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.sessions.SessionList session_list = 7;</code>
       */
      public Builder setSessionList(ubii.sessions.SessionOuterClass.SessionList value) {
        if (sessionListBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          sessionListBuilder_.setMessage(value);
        }
        typeCase_ = 7;
        return this;
      }
      /**
       * <code>.ubii.sessions.SessionList session_list = 7;</code>
       */
      public Builder setSessionList(
          ubii.sessions.SessionOuterClass.SessionList.Builder builderForValue) {
        if (sessionListBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          sessionListBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 7;
        return this;
      }
      /**
       * <code>.ubii.sessions.SessionList session_list = 7;</code>
       */
      public Builder mergeSessionList(ubii.sessions.SessionOuterClass.SessionList value) {
        if (sessionListBuilder_ == null) {
          if (typeCase_ == 7 &&
              type_ != ubii.sessions.SessionOuterClass.SessionList.getDefaultInstance()) {
            type_ = ubii.sessions.SessionOuterClass.SessionList.newBuilder((ubii.sessions.SessionOuterClass.SessionList) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 7) {
            sessionListBuilder_.mergeFrom(value);
          }
          sessionListBuilder_.setMessage(value);
        }
        typeCase_ = 7;
        return this;
      }
      /**
       * <code>.ubii.sessions.SessionList session_list = 7;</code>
       */
      public Builder clearSessionList() {
        if (sessionListBuilder_ == null) {
          if (typeCase_ == 7) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 7) {
            typeCase_ = 0;
            type_ = null;
          }
          sessionListBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.sessions.SessionList session_list = 7;</code>
       */
      public ubii.sessions.SessionOuterClass.SessionList.Builder getSessionListBuilder() {
        return getSessionListFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.sessions.SessionList session_list = 7;</code>
       */
      public ubii.sessions.SessionOuterClass.SessionListOrBuilder getSessionListOrBuilder() {
        if ((typeCase_ == 7) && (sessionListBuilder_ != null)) {
          return sessionListBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 7) {
            return (ubii.sessions.SessionOuterClass.SessionList) type_;
          }
          return ubii.sessions.SessionOuterClass.SessionList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.sessions.SessionList session_list = 7;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.sessions.SessionOuterClass.SessionList, ubii.sessions.SessionOuterClass.SessionList.Builder, ubii.sessions.SessionOuterClass.SessionListOrBuilder> 
          getSessionListFieldBuilder() {
        if (sessionListBuilder_ == null) {
          if (!(typeCase_ == 7)) {
            type_ = ubii.sessions.SessionOuterClass.SessionList.getDefaultInstance();
          }
          sessionListBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.sessions.SessionOuterClass.SessionList, ubii.sessions.SessionOuterClass.SessionList.Builder, ubii.sessions.SessionOuterClass.SessionListOrBuilder>(
                  (ubii.sessions.SessionOuterClass.SessionList) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 7;
        onChanged();;
        return sessionListBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.processing.ProcessingModuleOuterClass.ProcessingModule, ubii.processing.ProcessingModuleOuterClass.ProcessingModule.Builder, ubii.processing.ProcessingModuleOuterClass.ProcessingModuleOrBuilder> processingModuleBuilder_;
      /**
       * <code>.ubii.processing.ProcessingModule processing_module = 8;</code>
       */
      public boolean hasProcessingModule() {
        return typeCase_ == 8;
      }
      /**
       * <code>.ubii.processing.ProcessingModule processing_module = 8;</code>
       */
      public ubii.processing.ProcessingModuleOuterClass.ProcessingModule getProcessingModule() {
        if (processingModuleBuilder_ == null) {
          if (typeCase_ == 8) {
            return (ubii.processing.ProcessingModuleOuterClass.ProcessingModule) type_;
          }
          return ubii.processing.ProcessingModuleOuterClass.ProcessingModule.getDefaultInstance();
        } else {
          if (typeCase_ == 8) {
            return processingModuleBuilder_.getMessage();
          }
          return ubii.processing.ProcessingModuleOuterClass.ProcessingModule.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.processing.ProcessingModule processing_module = 8;</code>
       */
      public Builder setProcessingModule(ubii.processing.ProcessingModuleOuterClass.ProcessingModule value) {
        if (processingModuleBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          processingModuleBuilder_.setMessage(value);
        }
        typeCase_ = 8;
        return this;
      }
      /**
       * <code>.ubii.processing.ProcessingModule processing_module = 8;</code>
       */
      public Builder setProcessingModule(
          ubii.processing.ProcessingModuleOuterClass.ProcessingModule.Builder builderForValue) {
        if (processingModuleBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          processingModuleBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 8;
        return this;
      }
      /**
       * <code>.ubii.processing.ProcessingModule processing_module = 8;</code>
       */
      public Builder mergeProcessingModule(ubii.processing.ProcessingModuleOuterClass.ProcessingModule value) {
        if (processingModuleBuilder_ == null) {
          if (typeCase_ == 8 &&
              type_ != ubii.processing.ProcessingModuleOuterClass.ProcessingModule.getDefaultInstance()) {
            type_ = ubii.processing.ProcessingModuleOuterClass.ProcessingModule.newBuilder((ubii.processing.ProcessingModuleOuterClass.ProcessingModule) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 8) {
            processingModuleBuilder_.mergeFrom(value);
          }
          processingModuleBuilder_.setMessage(value);
        }
        typeCase_ = 8;
        return this;
      }
      /**
       * <code>.ubii.processing.ProcessingModule processing_module = 8;</code>
       */
      public Builder clearProcessingModule() {
        if (processingModuleBuilder_ == null) {
          if (typeCase_ == 8) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 8) {
            typeCase_ = 0;
            type_ = null;
          }
          processingModuleBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.processing.ProcessingModule processing_module = 8;</code>
       */
      public ubii.processing.ProcessingModuleOuterClass.ProcessingModule.Builder getProcessingModuleBuilder() {
        return getProcessingModuleFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.processing.ProcessingModule processing_module = 8;</code>
       */
      public ubii.processing.ProcessingModuleOuterClass.ProcessingModuleOrBuilder getProcessingModuleOrBuilder() {
        if ((typeCase_ == 8) && (processingModuleBuilder_ != null)) {
          return processingModuleBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 8) {
            return (ubii.processing.ProcessingModuleOuterClass.ProcessingModule) type_;
          }
          return ubii.processing.ProcessingModuleOuterClass.ProcessingModule.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.processing.ProcessingModule processing_module = 8;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.processing.ProcessingModuleOuterClass.ProcessingModule, ubii.processing.ProcessingModuleOuterClass.ProcessingModule.Builder, ubii.processing.ProcessingModuleOuterClass.ProcessingModuleOrBuilder> 
          getProcessingModuleFieldBuilder() {
        if (processingModuleBuilder_ == null) {
          if (!(typeCase_ == 8)) {
            type_ = ubii.processing.ProcessingModuleOuterClass.ProcessingModule.getDefaultInstance();
          }
          processingModuleBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.processing.ProcessingModuleOuterClass.ProcessingModule, ubii.processing.ProcessingModuleOuterClass.ProcessingModule.Builder, ubii.processing.ProcessingModuleOuterClass.ProcessingModuleOrBuilder>(
                  (ubii.processing.ProcessingModuleOuterClass.ProcessingModule) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 8;
        onChanged();;
        return processingModuleBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.processing.ProcessingModuleOuterClass.ProcessingModuleList, ubii.processing.ProcessingModuleOuterClass.ProcessingModuleList.Builder, ubii.processing.ProcessingModuleOuterClass.ProcessingModuleListOrBuilder> processingModuleListBuilder_;
      /**
       * <code>.ubii.processing.ProcessingModuleList processing_module_list = 9;</code>
       */
      public boolean hasProcessingModuleList() {
        return typeCase_ == 9;
      }
      /**
       * <code>.ubii.processing.ProcessingModuleList processing_module_list = 9;</code>
       */
      public ubii.processing.ProcessingModuleOuterClass.ProcessingModuleList getProcessingModuleList() {
        if (processingModuleListBuilder_ == null) {
          if (typeCase_ == 9) {
            return (ubii.processing.ProcessingModuleOuterClass.ProcessingModuleList) type_;
          }
          return ubii.processing.ProcessingModuleOuterClass.ProcessingModuleList.getDefaultInstance();
        } else {
          if (typeCase_ == 9) {
            return processingModuleListBuilder_.getMessage();
          }
          return ubii.processing.ProcessingModuleOuterClass.ProcessingModuleList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.processing.ProcessingModuleList processing_module_list = 9;</code>
       */
      public Builder setProcessingModuleList(ubii.processing.ProcessingModuleOuterClass.ProcessingModuleList value) {
        if (processingModuleListBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          processingModuleListBuilder_.setMessage(value);
        }
        typeCase_ = 9;
        return this;
      }
      /**
       * <code>.ubii.processing.ProcessingModuleList processing_module_list = 9;</code>
       */
      public Builder setProcessingModuleList(
          ubii.processing.ProcessingModuleOuterClass.ProcessingModuleList.Builder builderForValue) {
        if (processingModuleListBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          processingModuleListBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 9;
        return this;
      }
      /**
       * <code>.ubii.processing.ProcessingModuleList processing_module_list = 9;</code>
       */
      public Builder mergeProcessingModuleList(ubii.processing.ProcessingModuleOuterClass.ProcessingModuleList value) {
        if (processingModuleListBuilder_ == null) {
          if (typeCase_ == 9 &&
              type_ != ubii.processing.ProcessingModuleOuterClass.ProcessingModuleList.getDefaultInstance()) {
            type_ = ubii.processing.ProcessingModuleOuterClass.ProcessingModuleList.newBuilder((ubii.processing.ProcessingModuleOuterClass.ProcessingModuleList) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 9) {
            processingModuleListBuilder_.mergeFrom(value);
          }
          processingModuleListBuilder_.setMessage(value);
        }
        typeCase_ = 9;
        return this;
      }
      /**
       * <code>.ubii.processing.ProcessingModuleList processing_module_list = 9;</code>
       */
      public Builder clearProcessingModuleList() {
        if (processingModuleListBuilder_ == null) {
          if (typeCase_ == 9) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 9) {
            typeCase_ = 0;
            type_ = null;
          }
          processingModuleListBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.processing.ProcessingModuleList processing_module_list = 9;</code>
       */
      public ubii.processing.ProcessingModuleOuterClass.ProcessingModuleList.Builder getProcessingModuleListBuilder() {
        return getProcessingModuleListFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.processing.ProcessingModuleList processing_module_list = 9;</code>
       */
      public ubii.processing.ProcessingModuleOuterClass.ProcessingModuleListOrBuilder getProcessingModuleListOrBuilder() {
        if ((typeCase_ == 9) && (processingModuleListBuilder_ != null)) {
          return processingModuleListBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 9) {
            return (ubii.processing.ProcessingModuleOuterClass.ProcessingModuleList) type_;
          }
          return ubii.processing.ProcessingModuleOuterClass.ProcessingModuleList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.processing.ProcessingModuleList processing_module_list = 9;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.processing.ProcessingModuleOuterClass.ProcessingModuleList, ubii.processing.ProcessingModuleOuterClass.ProcessingModuleList.Builder, ubii.processing.ProcessingModuleOuterClass.ProcessingModuleListOrBuilder> 
          getProcessingModuleListFieldBuilder() {
        if (processingModuleListBuilder_ == null) {
          if (!(typeCase_ == 9)) {
            type_ = ubii.processing.ProcessingModuleOuterClass.ProcessingModuleList.getDefaultInstance();
          }
          processingModuleListBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.processing.ProcessingModuleOuterClass.ProcessingModuleList, ubii.processing.ProcessingModuleOuterClass.ProcessingModuleList.Builder, ubii.processing.ProcessingModuleOuterClass.ProcessingModuleListOrBuilder>(
                  (ubii.processing.ProcessingModuleOuterClass.ProcessingModuleList) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 9;
        onChanged();;
        return processingModuleListBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Lists.StringList, ubii.dataStructure.Lists.StringList.Builder, ubii.dataStructure.Lists.StringListOrBuilder> stringListBuilder_;
      /**
       * <code>.ubii.dataStructure.StringList string_list = 10;</code>
       */
      public boolean hasStringList() {
        return typeCase_ == 10;
      }
      /**
       * <code>.ubii.dataStructure.StringList string_list = 10;</code>
       */
      public ubii.dataStructure.Lists.StringList getStringList() {
        if (stringListBuilder_ == null) {
          if (typeCase_ == 10) {
            return (ubii.dataStructure.Lists.StringList) type_;
          }
          return ubii.dataStructure.Lists.StringList.getDefaultInstance();
        } else {
          if (typeCase_ == 10) {
            return stringListBuilder_.getMessage();
          }
          return ubii.dataStructure.Lists.StringList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.StringList string_list = 10;</code>
       */
      public Builder setStringList(ubii.dataStructure.Lists.StringList value) {
        if (stringListBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          stringListBuilder_.setMessage(value);
        }
        typeCase_ = 10;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.StringList string_list = 10;</code>
       */
      public Builder setStringList(
          ubii.dataStructure.Lists.StringList.Builder builderForValue) {
        if (stringListBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          stringListBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 10;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.StringList string_list = 10;</code>
       */
      public Builder mergeStringList(ubii.dataStructure.Lists.StringList value) {
        if (stringListBuilder_ == null) {
          if (typeCase_ == 10 &&
              type_ != ubii.dataStructure.Lists.StringList.getDefaultInstance()) {
            type_ = ubii.dataStructure.Lists.StringList.newBuilder((ubii.dataStructure.Lists.StringList) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 10) {
            stringListBuilder_.mergeFrom(value);
          }
          stringListBuilder_.setMessage(value);
        }
        typeCase_ = 10;
        return this;
      }
      /**
       * <code>.ubii.dataStructure.StringList string_list = 10;</code>
       */
      public Builder clearStringList() {
        if (stringListBuilder_ == null) {
          if (typeCase_ == 10) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 10) {
            typeCase_ = 0;
            type_ = null;
          }
          stringListBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.dataStructure.StringList string_list = 10;</code>
       */
      public ubii.dataStructure.Lists.StringList.Builder getStringListBuilder() {
        return getStringListFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.dataStructure.StringList string_list = 10;</code>
       */
      public ubii.dataStructure.Lists.StringListOrBuilder getStringListOrBuilder() {
        if ((typeCase_ == 10) && (stringListBuilder_ != null)) {
          return stringListBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 10) {
            return (ubii.dataStructure.Lists.StringList) type_;
          }
          return ubii.dataStructure.Lists.StringList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.dataStructure.StringList string_list = 10;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.dataStructure.Lists.StringList, ubii.dataStructure.Lists.StringList.Builder, ubii.dataStructure.Lists.StringListOrBuilder> 
          getStringListFieldBuilder() {
        if (stringListBuilder_ == null) {
          if (!(typeCase_ == 10)) {
            type_ = ubii.dataStructure.Lists.StringList.getDefaultInstance();
          }
          stringListBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.dataStructure.Lists.StringList, ubii.dataStructure.Lists.StringList.Builder, ubii.dataStructure.Lists.StringListOrBuilder>(
                  (ubii.dataStructure.Lists.StringList) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 10;
        onChanged();;
        return stringListBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.devices.TopicMuxOuterClass.TopicMux, ubii.devices.TopicMuxOuterClass.TopicMux.Builder, ubii.devices.TopicMuxOuterClass.TopicMuxOrBuilder> topicMuxBuilder_;
      /**
       * <code>.ubii.devices.TopicMux topic_mux = 11;</code>
       */
      public boolean hasTopicMux() {
        return typeCase_ == 11;
      }
      /**
       * <code>.ubii.devices.TopicMux topic_mux = 11;</code>
       */
      public ubii.devices.TopicMuxOuterClass.TopicMux getTopicMux() {
        if (topicMuxBuilder_ == null) {
          if (typeCase_ == 11) {
            return (ubii.devices.TopicMuxOuterClass.TopicMux) type_;
          }
          return ubii.devices.TopicMuxOuterClass.TopicMux.getDefaultInstance();
        } else {
          if (typeCase_ == 11) {
            return topicMuxBuilder_.getMessage();
          }
          return ubii.devices.TopicMuxOuterClass.TopicMux.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.devices.TopicMux topic_mux = 11;</code>
       */
      public Builder setTopicMux(ubii.devices.TopicMuxOuterClass.TopicMux value) {
        if (topicMuxBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          topicMuxBuilder_.setMessage(value);
        }
        typeCase_ = 11;
        return this;
      }
      /**
       * <code>.ubii.devices.TopicMux topic_mux = 11;</code>
       */
      public Builder setTopicMux(
          ubii.devices.TopicMuxOuterClass.TopicMux.Builder builderForValue) {
        if (topicMuxBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          topicMuxBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 11;
        return this;
      }
      /**
       * <code>.ubii.devices.TopicMux topic_mux = 11;</code>
       */
      public Builder mergeTopicMux(ubii.devices.TopicMuxOuterClass.TopicMux value) {
        if (topicMuxBuilder_ == null) {
          if (typeCase_ == 11 &&
              type_ != ubii.devices.TopicMuxOuterClass.TopicMux.getDefaultInstance()) {
            type_ = ubii.devices.TopicMuxOuterClass.TopicMux.newBuilder((ubii.devices.TopicMuxOuterClass.TopicMux) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 11) {
            topicMuxBuilder_.mergeFrom(value);
          }
          topicMuxBuilder_.setMessage(value);
        }
        typeCase_ = 11;
        return this;
      }
      /**
       * <code>.ubii.devices.TopicMux topic_mux = 11;</code>
       */
      public Builder clearTopicMux() {
        if (topicMuxBuilder_ == null) {
          if (typeCase_ == 11) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 11) {
            typeCase_ = 0;
            type_ = null;
          }
          topicMuxBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.devices.TopicMux topic_mux = 11;</code>
       */
      public ubii.devices.TopicMuxOuterClass.TopicMux.Builder getTopicMuxBuilder() {
        return getTopicMuxFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.devices.TopicMux topic_mux = 11;</code>
       */
      public ubii.devices.TopicMuxOuterClass.TopicMuxOrBuilder getTopicMuxOrBuilder() {
        if ((typeCase_ == 11) && (topicMuxBuilder_ != null)) {
          return topicMuxBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 11) {
            return (ubii.devices.TopicMuxOuterClass.TopicMux) type_;
          }
          return ubii.devices.TopicMuxOuterClass.TopicMux.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.devices.TopicMux topic_mux = 11;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.devices.TopicMuxOuterClass.TopicMux, ubii.devices.TopicMuxOuterClass.TopicMux.Builder, ubii.devices.TopicMuxOuterClass.TopicMuxOrBuilder> 
          getTopicMuxFieldBuilder() {
        if (topicMuxBuilder_ == null) {
          if (!(typeCase_ == 11)) {
            type_ = ubii.devices.TopicMuxOuterClass.TopicMux.getDefaultInstance();
          }
          topicMuxBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.devices.TopicMuxOuterClass.TopicMux, ubii.devices.TopicMuxOuterClass.TopicMux.Builder, ubii.devices.TopicMuxOuterClass.TopicMuxOrBuilder>(
                  (ubii.devices.TopicMuxOuterClass.TopicMux) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 11;
        onChanged();;
        return topicMuxBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.devices.TopicMuxOuterClass.TopicMuxList, ubii.devices.TopicMuxOuterClass.TopicMuxList.Builder, ubii.devices.TopicMuxOuterClass.TopicMuxListOrBuilder> topicMuxListBuilder_;
      /**
       * <code>.ubii.devices.TopicMuxList topic_mux_list = 12;</code>
       */
      public boolean hasTopicMuxList() {
        return typeCase_ == 12;
      }
      /**
       * <code>.ubii.devices.TopicMuxList topic_mux_list = 12;</code>
       */
      public ubii.devices.TopicMuxOuterClass.TopicMuxList getTopicMuxList() {
        if (topicMuxListBuilder_ == null) {
          if (typeCase_ == 12) {
            return (ubii.devices.TopicMuxOuterClass.TopicMuxList) type_;
          }
          return ubii.devices.TopicMuxOuterClass.TopicMuxList.getDefaultInstance();
        } else {
          if (typeCase_ == 12) {
            return topicMuxListBuilder_.getMessage();
          }
          return ubii.devices.TopicMuxOuterClass.TopicMuxList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.devices.TopicMuxList topic_mux_list = 12;</code>
       */
      public Builder setTopicMuxList(ubii.devices.TopicMuxOuterClass.TopicMuxList value) {
        if (topicMuxListBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          topicMuxListBuilder_.setMessage(value);
        }
        typeCase_ = 12;
        return this;
      }
      /**
       * <code>.ubii.devices.TopicMuxList topic_mux_list = 12;</code>
       */
      public Builder setTopicMuxList(
          ubii.devices.TopicMuxOuterClass.TopicMuxList.Builder builderForValue) {
        if (topicMuxListBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          topicMuxListBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 12;
        return this;
      }
      /**
       * <code>.ubii.devices.TopicMuxList topic_mux_list = 12;</code>
       */
      public Builder mergeTopicMuxList(ubii.devices.TopicMuxOuterClass.TopicMuxList value) {
        if (topicMuxListBuilder_ == null) {
          if (typeCase_ == 12 &&
              type_ != ubii.devices.TopicMuxOuterClass.TopicMuxList.getDefaultInstance()) {
            type_ = ubii.devices.TopicMuxOuterClass.TopicMuxList.newBuilder((ubii.devices.TopicMuxOuterClass.TopicMuxList) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 12) {
            topicMuxListBuilder_.mergeFrom(value);
          }
          topicMuxListBuilder_.setMessage(value);
        }
        typeCase_ = 12;
        return this;
      }
      /**
       * <code>.ubii.devices.TopicMuxList topic_mux_list = 12;</code>
       */
      public Builder clearTopicMuxList() {
        if (topicMuxListBuilder_ == null) {
          if (typeCase_ == 12) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 12) {
            typeCase_ = 0;
            type_ = null;
          }
          topicMuxListBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.devices.TopicMuxList topic_mux_list = 12;</code>
       */
      public ubii.devices.TopicMuxOuterClass.TopicMuxList.Builder getTopicMuxListBuilder() {
        return getTopicMuxListFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.devices.TopicMuxList topic_mux_list = 12;</code>
       */
      public ubii.devices.TopicMuxOuterClass.TopicMuxListOrBuilder getTopicMuxListOrBuilder() {
        if ((typeCase_ == 12) && (topicMuxListBuilder_ != null)) {
          return topicMuxListBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 12) {
            return (ubii.devices.TopicMuxOuterClass.TopicMuxList) type_;
          }
          return ubii.devices.TopicMuxOuterClass.TopicMuxList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.devices.TopicMuxList topic_mux_list = 12;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.devices.TopicMuxOuterClass.TopicMuxList, ubii.devices.TopicMuxOuterClass.TopicMuxList.Builder, ubii.devices.TopicMuxOuterClass.TopicMuxListOrBuilder> 
          getTopicMuxListFieldBuilder() {
        if (topicMuxListBuilder_ == null) {
          if (!(typeCase_ == 12)) {
            type_ = ubii.devices.TopicMuxOuterClass.TopicMuxList.getDefaultInstance();
          }
          topicMuxListBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.devices.TopicMuxOuterClass.TopicMuxList, ubii.devices.TopicMuxOuterClass.TopicMuxList.Builder, ubii.devices.TopicMuxOuterClass.TopicMuxListOrBuilder>(
                  (ubii.devices.TopicMuxOuterClass.TopicMuxList) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 12;
        onChanged();;
        return topicMuxListBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.devices.TopicDemuxOuterClass.TopicDemux, ubii.devices.TopicDemuxOuterClass.TopicDemux.Builder, ubii.devices.TopicDemuxOuterClass.TopicDemuxOrBuilder> topicDemuxBuilder_;
      /**
       * <code>.ubii.devices.TopicDemux topic_demux = 13;</code>
       */
      public boolean hasTopicDemux() {
        return typeCase_ == 13;
      }
      /**
       * <code>.ubii.devices.TopicDemux topic_demux = 13;</code>
       */
      public ubii.devices.TopicDemuxOuterClass.TopicDemux getTopicDemux() {
        if (topicDemuxBuilder_ == null) {
          if (typeCase_ == 13) {
            return (ubii.devices.TopicDemuxOuterClass.TopicDemux) type_;
          }
          return ubii.devices.TopicDemuxOuterClass.TopicDemux.getDefaultInstance();
        } else {
          if (typeCase_ == 13) {
            return topicDemuxBuilder_.getMessage();
          }
          return ubii.devices.TopicDemuxOuterClass.TopicDemux.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.devices.TopicDemux topic_demux = 13;</code>
       */
      public Builder setTopicDemux(ubii.devices.TopicDemuxOuterClass.TopicDemux value) {
        if (topicDemuxBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          topicDemuxBuilder_.setMessage(value);
        }
        typeCase_ = 13;
        return this;
      }
      /**
       * <code>.ubii.devices.TopicDemux topic_demux = 13;</code>
       */
      public Builder setTopicDemux(
          ubii.devices.TopicDemuxOuterClass.TopicDemux.Builder builderForValue) {
        if (topicDemuxBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          topicDemuxBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 13;
        return this;
      }
      /**
       * <code>.ubii.devices.TopicDemux topic_demux = 13;</code>
       */
      public Builder mergeTopicDemux(ubii.devices.TopicDemuxOuterClass.TopicDemux value) {
        if (topicDemuxBuilder_ == null) {
          if (typeCase_ == 13 &&
              type_ != ubii.devices.TopicDemuxOuterClass.TopicDemux.getDefaultInstance()) {
            type_ = ubii.devices.TopicDemuxOuterClass.TopicDemux.newBuilder((ubii.devices.TopicDemuxOuterClass.TopicDemux) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 13) {
            topicDemuxBuilder_.mergeFrom(value);
          }
          topicDemuxBuilder_.setMessage(value);
        }
        typeCase_ = 13;
        return this;
      }
      /**
       * <code>.ubii.devices.TopicDemux topic_demux = 13;</code>
       */
      public Builder clearTopicDemux() {
        if (topicDemuxBuilder_ == null) {
          if (typeCase_ == 13) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 13) {
            typeCase_ = 0;
            type_ = null;
          }
          topicDemuxBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.devices.TopicDemux topic_demux = 13;</code>
       */
      public ubii.devices.TopicDemuxOuterClass.TopicDemux.Builder getTopicDemuxBuilder() {
        return getTopicDemuxFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.devices.TopicDemux topic_demux = 13;</code>
       */
      public ubii.devices.TopicDemuxOuterClass.TopicDemuxOrBuilder getTopicDemuxOrBuilder() {
        if ((typeCase_ == 13) && (topicDemuxBuilder_ != null)) {
          return topicDemuxBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 13) {
            return (ubii.devices.TopicDemuxOuterClass.TopicDemux) type_;
          }
          return ubii.devices.TopicDemuxOuterClass.TopicDemux.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.devices.TopicDemux topic_demux = 13;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.devices.TopicDemuxOuterClass.TopicDemux, ubii.devices.TopicDemuxOuterClass.TopicDemux.Builder, ubii.devices.TopicDemuxOuterClass.TopicDemuxOrBuilder> 
          getTopicDemuxFieldBuilder() {
        if (topicDemuxBuilder_ == null) {
          if (!(typeCase_ == 13)) {
            type_ = ubii.devices.TopicDemuxOuterClass.TopicDemux.getDefaultInstance();
          }
          topicDemuxBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.devices.TopicDemuxOuterClass.TopicDemux, ubii.devices.TopicDemuxOuterClass.TopicDemux.Builder, ubii.devices.TopicDemuxOuterClass.TopicDemuxOrBuilder>(
                  (ubii.devices.TopicDemuxOuterClass.TopicDemux) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 13;
        onChanged();;
        return topicDemuxBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.devices.TopicDemuxOuterClass.TopicDemuxList, ubii.devices.TopicDemuxOuterClass.TopicDemuxList.Builder, ubii.devices.TopicDemuxOuterClass.TopicDemuxListOrBuilder> topicDemuxListBuilder_;
      /**
       * <code>.ubii.devices.TopicDemuxList topic_demux_list = 14;</code>
       */
      public boolean hasTopicDemuxList() {
        return typeCase_ == 14;
      }
      /**
       * <code>.ubii.devices.TopicDemuxList topic_demux_list = 14;</code>
       */
      public ubii.devices.TopicDemuxOuterClass.TopicDemuxList getTopicDemuxList() {
        if (topicDemuxListBuilder_ == null) {
          if (typeCase_ == 14) {
            return (ubii.devices.TopicDemuxOuterClass.TopicDemuxList) type_;
          }
          return ubii.devices.TopicDemuxOuterClass.TopicDemuxList.getDefaultInstance();
        } else {
          if (typeCase_ == 14) {
            return topicDemuxListBuilder_.getMessage();
          }
          return ubii.devices.TopicDemuxOuterClass.TopicDemuxList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.devices.TopicDemuxList topic_demux_list = 14;</code>
       */
      public Builder setTopicDemuxList(ubii.devices.TopicDemuxOuterClass.TopicDemuxList value) {
        if (topicDemuxListBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          topicDemuxListBuilder_.setMessage(value);
        }
        typeCase_ = 14;
        return this;
      }
      /**
       * <code>.ubii.devices.TopicDemuxList topic_demux_list = 14;</code>
       */
      public Builder setTopicDemuxList(
          ubii.devices.TopicDemuxOuterClass.TopicDemuxList.Builder builderForValue) {
        if (topicDemuxListBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          topicDemuxListBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 14;
        return this;
      }
      /**
       * <code>.ubii.devices.TopicDemuxList topic_demux_list = 14;</code>
       */
      public Builder mergeTopicDemuxList(ubii.devices.TopicDemuxOuterClass.TopicDemuxList value) {
        if (topicDemuxListBuilder_ == null) {
          if (typeCase_ == 14 &&
              type_ != ubii.devices.TopicDemuxOuterClass.TopicDemuxList.getDefaultInstance()) {
            type_ = ubii.devices.TopicDemuxOuterClass.TopicDemuxList.newBuilder((ubii.devices.TopicDemuxOuterClass.TopicDemuxList) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 14) {
            topicDemuxListBuilder_.mergeFrom(value);
          }
          topicDemuxListBuilder_.setMessage(value);
        }
        typeCase_ = 14;
        return this;
      }
      /**
       * <code>.ubii.devices.TopicDemuxList topic_demux_list = 14;</code>
       */
      public Builder clearTopicDemuxList() {
        if (topicDemuxListBuilder_ == null) {
          if (typeCase_ == 14) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 14) {
            typeCase_ = 0;
            type_ = null;
          }
          topicDemuxListBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.devices.TopicDemuxList topic_demux_list = 14;</code>
       */
      public ubii.devices.TopicDemuxOuterClass.TopicDemuxList.Builder getTopicDemuxListBuilder() {
        return getTopicDemuxListFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.devices.TopicDemuxList topic_demux_list = 14;</code>
       */
      public ubii.devices.TopicDemuxOuterClass.TopicDemuxListOrBuilder getTopicDemuxListOrBuilder() {
        if ((typeCase_ == 14) && (topicDemuxListBuilder_ != null)) {
          return topicDemuxListBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 14) {
            return (ubii.devices.TopicDemuxOuterClass.TopicDemuxList) type_;
          }
          return ubii.devices.TopicDemuxOuterClass.TopicDemuxList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.devices.TopicDemuxList topic_demux_list = 14;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.devices.TopicDemuxOuterClass.TopicDemuxList, ubii.devices.TopicDemuxOuterClass.TopicDemuxList.Builder, ubii.devices.TopicDemuxOuterClass.TopicDemuxListOrBuilder> 
          getTopicDemuxListFieldBuilder() {
        if (topicDemuxListBuilder_ == null) {
          if (!(typeCase_ == 14)) {
            type_ = ubii.devices.TopicDemuxOuterClass.TopicDemuxList.getDefaultInstance();
          }
          topicDemuxListBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.devices.TopicDemuxOuterClass.TopicDemuxList, ubii.devices.TopicDemuxOuterClass.TopicDemuxList.Builder, ubii.devices.TopicDemuxOuterClass.TopicDemuxListOrBuilder>(
                  (ubii.devices.TopicDemuxOuterClass.TopicDemuxList) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 14;
        onChanged();;
        return topicDemuxListBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.clients.ClientOuterClass.ClientList, ubii.clients.ClientOuterClass.ClientList.Builder, ubii.clients.ClientOuterClass.ClientListOrBuilder> clientListBuilder_;
      /**
       * <code>.ubii.clients.ClientList client_list = 15;</code>
       */
      public boolean hasClientList() {
        return typeCase_ == 15;
      }
      /**
       * <code>.ubii.clients.ClientList client_list = 15;</code>
       */
      public ubii.clients.ClientOuterClass.ClientList getClientList() {
        if (clientListBuilder_ == null) {
          if (typeCase_ == 15) {
            return (ubii.clients.ClientOuterClass.ClientList) type_;
          }
          return ubii.clients.ClientOuterClass.ClientList.getDefaultInstance();
        } else {
          if (typeCase_ == 15) {
            return clientListBuilder_.getMessage();
          }
          return ubii.clients.ClientOuterClass.ClientList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.clients.ClientList client_list = 15;</code>
       */
      public Builder setClientList(ubii.clients.ClientOuterClass.ClientList value) {
        if (clientListBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          clientListBuilder_.setMessage(value);
        }
        typeCase_ = 15;
        return this;
      }
      /**
       * <code>.ubii.clients.ClientList client_list = 15;</code>
       */
      public Builder setClientList(
          ubii.clients.ClientOuterClass.ClientList.Builder builderForValue) {
        if (clientListBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          clientListBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 15;
        return this;
      }
      /**
       * <code>.ubii.clients.ClientList client_list = 15;</code>
       */
      public Builder mergeClientList(ubii.clients.ClientOuterClass.ClientList value) {
        if (clientListBuilder_ == null) {
          if (typeCase_ == 15 &&
              type_ != ubii.clients.ClientOuterClass.ClientList.getDefaultInstance()) {
            type_ = ubii.clients.ClientOuterClass.ClientList.newBuilder((ubii.clients.ClientOuterClass.ClientList) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 15) {
            clientListBuilder_.mergeFrom(value);
          }
          clientListBuilder_.setMessage(value);
        }
        typeCase_ = 15;
        return this;
      }
      /**
       * <code>.ubii.clients.ClientList client_list = 15;</code>
       */
      public Builder clearClientList() {
        if (clientListBuilder_ == null) {
          if (typeCase_ == 15) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 15) {
            typeCase_ = 0;
            type_ = null;
          }
          clientListBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.clients.ClientList client_list = 15;</code>
       */
      public ubii.clients.ClientOuterClass.ClientList.Builder getClientListBuilder() {
        return getClientListFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.clients.ClientList client_list = 15;</code>
       */
      public ubii.clients.ClientOuterClass.ClientListOrBuilder getClientListOrBuilder() {
        if ((typeCase_ == 15) && (clientListBuilder_ != null)) {
          return clientListBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 15) {
            return (ubii.clients.ClientOuterClass.ClientList) type_;
          }
          return ubii.clients.ClientOuterClass.ClientList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.clients.ClientList client_list = 15;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.clients.ClientOuterClass.ClientList, ubii.clients.ClientOuterClass.ClientList.Builder, ubii.clients.ClientOuterClass.ClientListOrBuilder> 
          getClientListFieldBuilder() {
        if (clientListBuilder_ == null) {
          if (!(typeCase_ == 15)) {
            type_ = ubii.clients.ClientOuterClass.ClientList.getDefaultInstance();
          }
          clientListBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.clients.ClientOuterClass.ClientList, ubii.clients.ClientOuterClass.ClientList.Builder, ubii.clients.ClientOuterClass.ClientListOrBuilder>(
                  (ubii.clients.ClientOuterClass.ClientList) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 15;
        onChanged();;
        return clientListBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.devices.DeviceOuterClass.DeviceList, ubii.devices.DeviceOuterClass.DeviceList.Builder, ubii.devices.DeviceOuterClass.DeviceListOrBuilder> deviceListBuilder_;
      /**
       * <code>.ubii.devices.DeviceList device_list = 16;</code>
       */
      public boolean hasDeviceList() {
        return typeCase_ == 16;
      }
      /**
       * <code>.ubii.devices.DeviceList device_list = 16;</code>
       */
      public ubii.devices.DeviceOuterClass.DeviceList getDeviceList() {
        if (deviceListBuilder_ == null) {
          if (typeCase_ == 16) {
            return (ubii.devices.DeviceOuterClass.DeviceList) type_;
          }
          return ubii.devices.DeviceOuterClass.DeviceList.getDefaultInstance();
        } else {
          if (typeCase_ == 16) {
            return deviceListBuilder_.getMessage();
          }
          return ubii.devices.DeviceOuterClass.DeviceList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.devices.DeviceList device_list = 16;</code>
       */
      public Builder setDeviceList(ubii.devices.DeviceOuterClass.DeviceList value) {
        if (deviceListBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          deviceListBuilder_.setMessage(value);
        }
        typeCase_ = 16;
        return this;
      }
      /**
       * <code>.ubii.devices.DeviceList device_list = 16;</code>
       */
      public Builder setDeviceList(
          ubii.devices.DeviceOuterClass.DeviceList.Builder builderForValue) {
        if (deviceListBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          deviceListBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 16;
        return this;
      }
      /**
       * <code>.ubii.devices.DeviceList device_list = 16;</code>
       */
      public Builder mergeDeviceList(ubii.devices.DeviceOuterClass.DeviceList value) {
        if (deviceListBuilder_ == null) {
          if (typeCase_ == 16 &&
              type_ != ubii.devices.DeviceOuterClass.DeviceList.getDefaultInstance()) {
            type_ = ubii.devices.DeviceOuterClass.DeviceList.newBuilder((ubii.devices.DeviceOuterClass.DeviceList) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 16) {
            deviceListBuilder_.mergeFrom(value);
          }
          deviceListBuilder_.setMessage(value);
        }
        typeCase_ = 16;
        return this;
      }
      /**
       * <code>.ubii.devices.DeviceList device_list = 16;</code>
       */
      public Builder clearDeviceList() {
        if (deviceListBuilder_ == null) {
          if (typeCase_ == 16) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 16) {
            typeCase_ = 0;
            type_ = null;
          }
          deviceListBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.devices.DeviceList device_list = 16;</code>
       */
      public ubii.devices.DeviceOuterClass.DeviceList.Builder getDeviceListBuilder() {
        return getDeviceListFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.devices.DeviceList device_list = 16;</code>
       */
      public ubii.devices.DeviceOuterClass.DeviceListOrBuilder getDeviceListOrBuilder() {
        if ((typeCase_ == 16) && (deviceListBuilder_ != null)) {
          return deviceListBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 16) {
            return (ubii.devices.DeviceOuterClass.DeviceList) type_;
          }
          return ubii.devices.DeviceOuterClass.DeviceList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.devices.DeviceList device_list = 16;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.devices.DeviceOuterClass.DeviceList, ubii.devices.DeviceOuterClass.DeviceList.Builder, ubii.devices.DeviceOuterClass.DeviceListOrBuilder> 
          getDeviceListFieldBuilder() {
        if (deviceListBuilder_ == null) {
          if (!(typeCase_ == 16)) {
            type_ = ubii.devices.DeviceOuterClass.DeviceList.getDefaultInstance();
          }
          deviceListBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.devices.DeviceOuterClass.DeviceList, ubii.devices.DeviceOuterClass.DeviceList.Builder, ubii.devices.DeviceOuterClass.DeviceListOrBuilder>(
                  (ubii.devices.DeviceOuterClass.DeviceList) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 16;
        onChanged();;
        return deviceListBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.services.ServiceOuterClass.Service, ubii.services.ServiceOuterClass.Service.Builder, ubii.services.ServiceOuterClass.ServiceOrBuilder> serviceBuilder_;
      /**
       * <code>.ubii.services.Service service = 17;</code>
       */
      public boolean hasService() {
        return typeCase_ == 17;
      }
      /**
       * <code>.ubii.services.Service service = 17;</code>
       */
      public ubii.services.ServiceOuterClass.Service getService() {
        if (serviceBuilder_ == null) {
          if (typeCase_ == 17) {
            return (ubii.services.ServiceOuterClass.Service) type_;
          }
          return ubii.services.ServiceOuterClass.Service.getDefaultInstance();
        } else {
          if (typeCase_ == 17) {
            return serviceBuilder_.getMessage();
          }
          return ubii.services.ServiceOuterClass.Service.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.services.Service service = 17;</code>
       */
      public Builder setService(ubii.services.ServiceOuterClass.Service value) {
        if (serviceBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          serviceBuilder_.setMessage(value);
        }
        typeCase_ = 17;
        return this;
      }
      /**
       * <code>.ubii.services.Service service = 17;</code>
       */
      public Builder setService(
          ubii.services.ServiceOuterClass.Service.Builder builderForValue) {
        if (serviceBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          serviceBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 17;
        return this;
      }
      /**
       * <code>.ubii.services.Service service = 17;</code>
       */
      public Builder mergeService(ubii.services.ServiceOuterClass.Service value) {
        if (serviceBuilder_ == null) {
          if (typeCase_ == 17 &&
              type_ != ubii.services.ServiceOuterClass.Service.getDefaultInstance()) {
            type_ = ubii.services.ServiceOuterClass.Service.newBuilder((ubii.services.ServiceOuterClass.Service) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 17) {
            serviceBuilder_.mergeFrom(value);
          }
          serviceBuilder_.setMessage(value);
        }
        typeCase_ = 17;
        return this;
      }
      /**
       * <code>.ubii.services.Service service = 17;</code>
       */
      public Builder clearService() {
        if (serviceBuilder_ == null) {
          if (typeCase_ == 17) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 17) {
            typeCase_ = 0;
            type_ = null;
          }
          serviceBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.services.Service service = 17;</code>
       */
      public ubii.services.ServiceOuterClass.Service.Builder getServiceBuilder() {
        return getServiceFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.services.Service service = 17;</code>
       */
      public ubii.services.ServiceOuterClass.ServiceOrBuilder getServiceOrBuilder() {
        if ((typeCase_ == 17) && (serviceBuilder_ != null)) {
          return serviceBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 17) {
            return (ubii.services.ServiceOuterClass.Service) type_;
          }
          return ubii.services.ServiceOuterClass.Service.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.services.Service service = 17;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.services.ServiceOuterClass.Service, ubii.services.ServiceOuterClass.Service.Builder, ubii.services.ServiceOuterClass.ServiceOrBuilder> 
          getServiceFieldBuilder() {
        if (serviceBuilder_ == null) {
          if (!(typeCase_ == 17)) {
            type_ = ubii.services.ServiceOuterClass.Service.getDefaultInstance();
          }
          serviceBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.services.ServiceOuterClass.Service, ubii.services.ServiceOuterClass.Service.Builder, ubii.services.ServiceOuterClass.ServiceOrBuilder>(
                  (ubii.services.ServiceOuterClass.Service) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 17;
        onChanged();;
        return serviceBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.services.ServiceOuterClass.ServiceList, ubii.services.ServiceOuterClass.ServiceList.Builder, ubii.services.ServiceOuterClass.ServiceListOrBuilder> serviceListBuilder_;
      /**
       * <code>.ubii.services.ServiceList service_list = 18;</code>
       */
      public boolean hasServiceList() {
        return typeCase_ == 18;
      }
      /**
       * <code>.ubii.services.ServiceList service_list = 18;</code>
       */
      public ubii.services.ServiceOuterClass.ServiceList getServiceList() {
        if (serviceListBuilder_ == null) {
          if (typeCase_ == 18) {
            return (ubii.services.ServiceOuterClass.ServiceList) type_;
          }
          return ubii.services.ServiceOuterClass.ServiceList.getDefaultInstance();
        } else {
          if (typeCase_ == 18) {
            return serviceListBuilder_.getMessage();
          }
          return ubii.services.ServiceOuterClass.ServiceList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.services.ServiceList service_list = 18;</code>
       */
      public Builder setServiceList(ubii.services.ServiceOuterClass.ServiceList value) {
        if (serviceListBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          serviceListBuilder_.setMessage(value);
        }
        typeCase_ = 18;
        return this;
      }
      /**
       * <code>.ubii.services.ServiceList service_list = 18;</code>
       */
      public Builder setServiceList(
          ubii.services.ServiceOuterClass.ServiceList.Builder builderForValue) {
        if (serviceListBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          serviceListBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 18;
        return this;
      }
      /**
       * <code>.ubii.services.ServiceList service_list = 18;</code>
       */
      public Builder mergeServiceList(ubii.services.ServiceOuterClass.ServiceList value) {
        if (serviceListBuilder_ == null) {
          if (typeCase_ == 18 &&
              type_ != ubii.services.ServiceOuterClass.ServiceList.getDefaultInstance()) {
            type_ = ubii.services.ServiceOuterClass.ServiceList.newBuilder((ubii.services.ServiceOuterClass.ServiceList) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 18) {
            serviceListBuilder_.mergeFrom(value);
          }
          serviceListBuilder_.setMessage(value);
        }
        typeCase_ = 18;
        return this;
      }
      /**
       * <code>.ubii.services.ServiceList service_list = 18;</code>
       */
      public Builder clearServiceList() {
        if (serviceListBuilder_ == null) {
          if (typeCase_ == 18) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 18) {
            typeCase_ = 0;
            type_ = null;
          }
          serviceListBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.services.ServiceList service_list = 18;</code>
       */
      public ubii.services.ServiceOuterClass.ServiceList.Builder getServiceListBuilder() {
        return getServiceListFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.services.ServiceList service_list = 18;</code>
       */
      public ubii.services.ServiceOuterClass.ServiceListOrBuilder getServiceListOrBuilder() {
        if ((typeCase_ == 18) && (serviceListBuilder_ != null)) {
          return serviceListBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 18) {
            return (ubii.services.ServiceOuterClass.ServiceList) type_;
          }
          return ubii.services.ServiceOuterClass.ServiceList.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.services.ServiceList service_list = 18;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.services.ServiceOuterClass.ServiceList, ubii.services.ServiceOuterClass.ServiceList.Builder, ubii.services.ServiceOuterClass.ServiceListOrBuilder> 
          getServiceListFieldBuilder() {
        if (serviceListBuilder_ == null) {
          if (!(typeCase_ == 18)) {
            type_ = ubii.services.ServiceOuterClass.ServiceList.getDefaultInstance();
          }
          serviceListBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.services.ServiceOuterClass.ServiceList, ubii.services.ServiceOuterClass.ServiceList.Builder, ubii.services.ServiceOuterClass.ServiceListOrBuilder>(
                  (ubii.services.ServiceOuterClass.ServiceList) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 18;
        onChanged();;
        return serviceListBuilder_;
      }

      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.processing.LockstepProcessing.LockstepProcessingReply, ubii.processing.LockstepProcessing.LockstepProcessingReply.Builder, ubii.processing.LockstepProcessing.LockstepProcessingReplyOrBuilder> lockstepProcessingReplyBuilder_;
      /**
       * <code>.ubii.processing.LockstepProcessingReply lockstep_processing_reply = 19;</code>
       */
      public boolean hasLockstepProcessingReply() {
        return typeCase_ == 19;
      }
      /**
       * <code>.ubii.processing.LockstepProcessingReply lockstep_processing_reply = 19;</code>
       */
      public ubii.processing.LockstepProcessing.LockstepProcessingReply getLockstepProcessingReply() {
        if (lockstepProcessingReplyBuilder_ == null) {
          if (typeCase_ == 19) {
            return (ubii.processing.LockstepProcessing.LockstepProcessingReply) type_;
          }
          return ubii.processing.LockstepProcessing.LockstepProcessingReply.getDefaultInstance();
        } else {
          if (typeCase_ == 19) {
            return lockstepProcessingReplyBuilder_.getMessage();
          }
          return ubii.processing.LockstepProcessing.LockstepProcessingReply.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.processing.LockstepProcessingReply lockstep_processing_reply = 19;</code>
       */
      public Builder setLockstepProcessingReply(ubii.processing.LockstepProcessing.LockstepProcessingReply value) {
        if (lockstepProcessingReplyBuilder_ == null) {
          if (value == null) {
            throw new NullPointerException();
          }
          type_ = value;
          onChanged();
        } else {
          lockstepProcessingReplyBuilder_.setMessage(value);
        }
        typeCase_ = 19;
        return this;
      }
      /**
       * <code>.ubii.processing.LockstepProcessingReply lockstep_processing_reply = 19;</code>
       */
      public Builder setLockstepProcessingReply(
          ubii.processing.LockstepProcessing.LockstepProcessingReply.Builder builderForValue) {
        if (lockstepProcessingReplyBuilder_ == null) {
          type_ = builderForValue.build();
          onChanged();
        } else {
          lockstepProcessingReplyBuilder_.setMessage(builderForValue.build());
        }
        typeCase_ = 19;
        return this;
      }
      /**
       * <code>.ubii.processing.LockstepProcessingReply lockstep_processing_reply = 19;</code>
       */
      public Builder mergeLockstepProcessingReply(ubii.processing.LockstepProcessing.LockstepProcessingReply value) {
        if (lockstepProcessingReplyBuilder_ == null) {
          if (typeCase_ == 19 &&
              type_ != ubii.processing.LockstepProcessing.LockstepProcessingReply.getDefaultInstance()) {
            type_ = ubii.processing.LockstepProcessing.LockstepProcessingReply.newBuilder((ubii.processing.LockstepProcessing.LockstepProcessingReply) type_)
                .mergeFrom(value).buildPartial();
          } else {
            type_ = value;
          }
          onChanged();
        } else {
          if (typeCase_ == 19) {
            lockstepProcessingReplyBuilder_.mergeFrom(value);
          }
          lockstepProcessingReplyBuilder_.setMessage(value);
        }
        typeCase_ = 19;
        return this;
      }
      /**
       * <code>.ubii.processing.LockstepProcessingReply lockstep_processing_reply = 19;</code>
       */
      public Builder clearLockstepProcessingReply() {
        if (lockstepProcessingReplyBuilder_ == null) {
          if (typeCase_ == 19) {
            typeCase_ = 0;
            type_ = null;
            onChanged();
          }
        } else {
          if (typeCase_ == 19) {
            typeCase_ = 0;
            type_ = null;
          }
          lockstepProcessingReplyBuilder_.clear();
        }
        return this;
      }
      /**
       * <code>.ubii.processing.LockstepProcessingReply lockstep_processing_reply = 19;</code>
       */
      public ubii.processing.LockstepProcessing.LockstepProcessingReply.Builder getLockstepProcessingReplyBuilder() {
        return getLockstepProcessingReplyFieldBuilder().getBuilder();
      }
      /**
       * <code>.ubii.processing.LockstepProcessingReply lockstep_processing_reply = 19;</code>
       */
      public ubii.processing.LockstepProcessing.LockstepProcessingReplyOrBuilder getLockstepProcessingReplyOrBuilder() {
        if ((typeCase_ == 19) && (lockstepProcessingReplyBuilder_ != null)) {
          return lockstepProcessingReplyBuilder_.getMessageOrBuilder();
        } else {
          if (typeCase_ == 19) {
            return (ubii.processing.LockstepProcessing.LockstepProcessingReply) type_;
          }
          return ubii.processing.LockstepProcessing.LockstepProcessingReply.getDefaultInstance();
        }
      }
      /**
       * <code>.ubii.processing.LockstepProcessingReply lockstep_processing_reply = 19;</code>
       */
      private com.google.protobuf.SingleFieldBuilderV3<
          ubii.processing.LockstepProcessing.LockstepProcessingReply, ubii.processing.LockstepProcessing.LockstepProcessingReply.Builder, ubii.processing.LockstepProcessing.LockstepProcessingReplyOrBuilder> 
          getLockstepProcessingReplyFieldBuilder() {
        if (lockstepProcessingReplyBuilder_ == null) {
          if (!(typeCase_ == 19)) {
            type_ = ubii.processing.LockstepProcessing.LockstepProcessingReply.getDefaultInstance();
          }
          lockstepProcessingReplyBuilder_ = new com.google.protobuf.SingleFieldBuilderV3<
              ubii.processing.LockstepProcessing.LockstepProcessingReply, ubii.processing.LockstepProcessing.LockstepProcessingReply.Builder, ubii.processing.LockstepProcessing.LockstepProcessingReplyOrBuilder>(
                  (ubii.processing.LockstepProcessing.LockstepProcessingReply) type_,
                  getParentForChildren(),
                  isClean());
          type_ = null;
        }
        typeCase_ = 19;
        onChanged();;
        return lockstepProcessingReplyBuilder_;
      }
      @java.lang.Override
      public final Builder setUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.setUnknownFieldsProto3(unknownFields);
      }

      @java.lang.Override
      public final Builder mergeUnknownFields(
          final com.google.protobuf.UnknownFieldSet unknownFields) {
        return super.mergeUnknownFields(unknownFields);
      }


      // @@protoc_insertion_point(builder_scope:ubii.services.ServiceReply)
    }

    // @@protoc_insertion_point(class_scope:ubii.services.ServiceReply)
    private static final ubii.services.ServiceReplyOuterClass.ServiceReply DEFAULT_INSTANCE;
    static {
      DEFAULT_INSTANCE = new ubii.services.ServiceReplyOuterClass.ServiceReply();
    }

    public static ubii.services.ServiceReplyOuterClass.ServiceReply getDefaultInstance() {
      return DEFAULT_INSTANCE;
    }

    private static final com.google.protobuf.Parser<ServiceReply>
        PARSER = new com.google.protobuf.AbstractParser<ServiceReply>() {
      @java.lang.Override
      public ServiceReply parsePartialFrom(
          com.google.protobuf.CodedInputStream input,
          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
          throws com.google.protobuf.InvalidProtocolBufferException {
        return new ServiceReply(input, extensionRegistry);
      }
    };

    public static com.google.protobuf.Parser<ServiceReply> parser() {
      return PARSER;
    }

    @java.lang.Override
    public com.google.protobuf.Parser<ServiceReply> getParserForType() {
      return PARSER;
    }

    @java.lang.Override
    public ubii.services.ServiceReplyOuterClass.ServiceReply getDefaultInstanceForType() {
      return DEFAULT_INSTANCE;
    }

  }

  private static final com.google.protobuf.Descriptors.Descriptor
    internal_static_ubii_services_ServiceReply_descriptor;
  private static final 
    com.google.protobuf.GeneratedMessageV3.FieldAccessorTable
      internal_static_ubii_services_ServiceReply_fieldAccessorTable;

  public static com.google.protobuf.Descriptors.FileDescriptor
      getDescriptor() {
    return descriptor;
  }
  private static  com.google.protobuf.Descriptors.FileDescriptor
      descriptor;
  static {
    java.lang.String[] descriptorData = {
      "\n!proto/services/serviceReply.proto\022\rubi" +
      "i.services\032\033proto/general/success.proto\032" +
      "\031proto/general/error.proto\0329proto/topicD" +
      "ata/topicDataRecord/dataStructure/lists." +
      "proto\032\032proto/clients/client.proto\032\032proto" +
      "/devices/device.proto\032\034proto/devices/top" +
      "icMux.proto\032\036proto/devices/topicDemux.pr" +
      "oto\032\032proto/servers/server.proto\032\034proto/s" +
      "essions/session.proto\032\034proto/services/se" +
      "rvice.proto\032\'proto/processing/processing" +
      "Module.proto\032)proto/processing/lockstepP" +
      "rocessing.proto\"\333\007\n\014ServiceReply\022(\n\007succ" +
      "ess\030\001 \001(\0132\025.ubii.general.SuccessH\000\022$\n\005er" +
      "ror\030\002 \001(\0132\023.ubii.general.ErrorH\000\022&\n\006clie" +
      "nt\030\003 \001(\0132\024.ubii.clients.ClientH\000\022&\n\006devi" +
      "ce\030\004 \001(\0132\024.ubii.devices.DeviceH\000\022&\n\006serv" +
      "er\030\005 \001(\0132\024.ubii.servers.ServerH\000\022)\n\007sess" +
      "ion\030\006 \001(\0132\026.ubii.sessions.SessionH\000\0222\n\014s" +
      "ession_list\030\007 \001(\0132\032.ubii.sessions.Sessio" +
      "nListH\000\022>\n\021processing_module\030\010 \001(\0132!.ubi" +
      "i.processing.ProcessingModuleH\000\022G\n\026proce" +
      "ssing_module_list\030\t \001(\0132%.ubii.processin" +
      "g.ProcessingModuleListH\000\0225\n\013string_list\030" +
      "\n \001(\0132\036.ubii.dataStructure.StringListH\000\022" +
      "+\n\ttopic_mux\030\013 \001(\0132\026.ubii.devices.TopicM" +
      "uxH\000\0224\n\016topic_mux_list\030\014 \001(\0132\032.ubii.devi" +
      "ces.TopicMuxListH\000\022/\n\013topic_demux\030\r \001(\0132" +
      "\030.ubii.devices.TopicDemuxH\000\0228\n\020topic_dem" +
      "ux_list\030\016 \001(\0132\034.ubii.devices.TopicDemuxL" +
      "istH\000\022/\n\013client_list\030\017 \001(\0132\030.ubii.client" +
      "s.ClientListH\000\022/\n\013device_list\030\020 \001(\0132\030.ub" +
      "ii.devices.DeviceListH\000\022)\n\007service\030\021 \001(\013" +
      "2\026.ubii.services.ServiceH\000\0222\n\014service_li" +
      "st\030\022 \001(\0132\032.ubii.services.ServiceListH\000\022M" +
      "\n\031lockstep_processing_reply\030\023 \001(\0132(.ubii" +
      ".processing.LockstepProcessingReplyH\000B\006\n" +
      "\004typeb\006proto3"
    };
    com.google.protobuf.Descriptors.FileDescriptor.InternalDescriptorAssigner assigner =
        new com.google.protobuf.Descriptors.FileDescriptor.    InternalDescriptorAssigner() {
          public com.google.protobuf.ExtensionRegistry assignDescriptors(
              com.google.protobuf.Descriptors.FileDescriptor root) {
            descriptor = root;
            return null;
          }
        };
    com.google.protobuf.Descriptors.FileDescriptor
      .internalBuildGeneratedFileFrom(descriptorData,
        new com.google.protobuf.Descriptors.FileDescriptor[] {
          ubii.general.SuccessOuterClass.getDescriptor(),
          ubii.general.ErrorOuterClass.getDescriptor(),
          ubii.dataStructure.Lists.getDescriptor(),
          ubii.clients.ClientOuterClass.getDescriptor(),
          ubii.devices.DeviceOuterClass.getDescriptor(),
          ubii.devices.TopicMuxOuterClass.getDescriptor(),
          ubii.devices.TopicDemuxOuterClass.getDescriptor(),
          ubii.servers.ServerOuterClass.getDescriptor(),
          ubii.sessions.SessionOuterClass.getDescriptor(),
          ubii.services.ServiceOuterClass.getDescriptor(),
          ubii.processing.ProcessingModuleOuterClass.getDescriptor(),
          ubii.processing.LockstepProcessing.getDescriptor(),
        }, assigner);
    internal_static_ubii_services_ServiceReply_descriptor =
      getDescriptor().getMessageTypes().get(0);
    internal_static_ubii_services_ServiceReply_fieldAccessorTable = new
      com.google.protobuf.GeneratedMessageV3.FieldAccessorTable(
        internal_static_ubii_services_ServiceReply_descriptor,
        new java.lang.String[] { "Success", "Error", "Client", "Device", "Server", "Session", "SessionList", "ProcessingModule", "ProcessingModuleList", "StringList", "TopicMux", "TopicMuxList", "TopicDemux", "TopicDemuxList", "ClientList", "DeviceList", "Service", "ServiceList", "LockstepProcessingReply", "Type", });
    ubii.general.SuccessOuterClass.getDescriptor();
    ubii.general.ErrorOuterClass.getDescriptor();
    ubii.dataStructure.Lists.getDescriptor();
    ubii.clients.ClientOuterClass.getDescriptor();
    ubii.devices.DeviceOuterClass.getDescriptor();
    ubii.devices.TopicMuxOuterClass.getDescriptor();
    ubii.devices.TopicDemuxOuterClass.getDescriptor();
    ubii.servers.ServerOuterClass.getDescriptor();
    ubii.sessions.SessionOuterClass.getDescriptor();
    ubii.services.ServiceOuterClass.getDescriptor();
    ubii.processing.ProcessingModuleOuterClass.getDescriptor();
    ubii.processing.LockstepProcessing.getDescriptor();
  }

  // @@protoc_insertion_point(outer_class_scope)
}
